<?php
	require_once("models/login.php");
	require_once("helpers/input.php");
	require_once("models/mymix_profile.php");
	require_once("helpers/filesystem.php");
	require_once("helpers/validate.php");

	Login::require_login();

	// helper functions for this controller

	// returns true on success, false otherwise
	function create_tar($source, $dest)
	{
		$command = "tar --directory " . dirname($source) . " -czf " . escapeshellarg($dest) . " " . basename($source);
		$junk_array = array();
		unset($junk_array);

		// remove the destination file if it exists
		if(file_exists($dest))
		{
			unlink($dest);
		}

		$command_retval = 0;
		exec($command, $junk_array, $command_retval);

		// return value of 0 means everything was ok
		return ($command_retval == 0);
	}

	function pull_online_device_configs()
	{
		// pull config from online devices before saving project
		$devices = Avahi::get_devices("mymix");
		foreach($devices as $mymix_device)
		{
			FTP::pull_all_mymix_config($this_device['ip_address'], $mac);
		}

		$devices = Avahi::get_devices("iex16");
		foreach($devices as $iex16_device)
		{
			FTP::pull_iex16_profile($iex16_device['ip_address'], $iex16_device['mac']);
		}
	}

	function export_local($export_type, $mac, $item_name, $export_name)
	{
		switch($export_type)
		{
			case "mymix-profile":
				$source = Config::get_item('mymix_devices_dir') . $mac . "/profiles/" . $item_name;
				$dest = Config::get_item('saved_mymix_profiles_dir') . $export_name;
				$redirect_url = "mymix-detail.php?mac=" . urlencode($mac);
				break;
			case "mymix-pref":
				$source = Config::get_item('mymix_devices_dir') . $mac . "/prefs";
				$dest = Config::get_item('saved_mymix_prefs_dir') . $export_name;
				$redirect_url = "mymix-detail.php?mac=" . urlencode($mac);
				break;
			case "mymix-lock":
				$source = Config::get_item('mymix_devices_dir') . $mac . "/menulock/menulock_mgr";
				$dest = Config::get_item('saved_mymix_locks_dir') . $export_name;
				$redirect_url = "mymix-detail.php?mac=" . urlencode($mac);
				break;
			case "iex16-pref":
				$source = Config::get_item('iex16_devices_dir') . $mac . "/prefs";
				$dest = Config::get_item('saved_iex16_prefs_dir') . $export_name;
				$redirect_url = "edit-iex16.php?mac=" . urlencode($mac);
				break;
			case "mymix-device":
				$source = Config::get_item('mymix_devices_dir') . $mac . "/";
				$dest = Config::get_item('saved_mymix_devices_dir') . $export_name;
				$redirect_url = "mymix-detail.php?mac=" . urlencode($mac);
				break;
			case "project":
				$source = Config::get_item('active_project_dir');
				$dest = Config::get_item('saved_projects_dir') . $export_name . Config::get_item('project_file_ext');
				$redirect_url = "save-load-project.php";
				break;
			default:
				throw new Exception("Unknown export type");
				break;
		}
		$dir = dirname($dest);
		Filesystem::mkdir_if_needed($dir);
		switch($export_type)
		{
			case "mymix-device":
			case "project":
				create_tar($source, $dest);
				break;
			default:
				copy($source, $dest);
				break;
		}
		Url::redirect($redirect_url);
	}

	function export_usb($export_type, $mac, $item_name, $export_name)
	{
		// make sure we don't try to save a file with a bad name
		$export_name = Filesystem::sanitize_filename_for_fat($export_name);
		switch($export_type)
		{
			case "mymix-profile":
				$source = Config::get_item('mymix_devices_dir') . $mac . "/profiles/" . $item_name;
				$dest = Config::get_item('external_mymix_profiles_dir') . $export_name;
				$redirect_url = "mymix-detail.php?mac=" . urlencode($mac);
				break;
			case "mymix-pref":
				$source = Config::get_item('mymix_devices_dir') . $mac . "/prefs";
				$dest = Config::get_item('external_mymix_prefs_dir') . $export_name;
				$redirect_url = "mymix-detail.php?mac=" . urlencode($mac);
				break;
			case "mymix-lock":
				$source = Config::get_item('mymix_devices_dir') . $mac . "/menulock/menulock_mgr";
				$dest = Config::get_item('external_mymix_locks_dir') . $export_name;
				$redirect_url = "mymix-detail.php?mac=" . urlencode($mac);
				break;
			case "iex16-pref":
				$source = Config::get_item('iex16_devices_dir') . $mac . "/prefs";
				$dest = Config::get_item('external_iex16_prefs_dir') . $export_name;
				$redirect_url = "edit-iex16.php?mac=" . urlencode($mac);
				break;
			case "mymix-device":
				$source = Config::get_item('mymix_devices_dir') . $mac . "/";
				$dest = Config::get_item('external_mymix_devices_dir') . $export_name;
				$redirect_url = "mymix-detail.php?mac=" . urlencode($mac);
				break;
			case "project":
				$source = Config::get_item('active_project_dir');
				$dest = Config::get_item('external_projects_dir') . $export_name . Config::get_item('project_file_ext');
				$redirect_url = "save-load-project.php";
				break;
			default:
				throw new Exception("Unknown export type");
				break;
		}
		$dir = dirname($dest);
		Filesystem::mkdir_if_needed($dir);
		switch($export_type)
		{
			case "mymix-device":
			case "project":
				$export_success = create_tar($source, $dest);
				break;
			default:
				$export_success = copy($source, $dest);
				break;
		}
		if(!$export_success)
		{
			die("USB export failed!");
		}

		// sync filesystem to make sure the file is actually written to disk
		Filesystem::sync();

		// redirect to the relavent url
		Url::redirect($redirect_url);
	}

	function export_browser($export_type, $mac, $item_name, $export_name)
	{
		switch($export_type)
		{
			case "mymix-profile":
				$source = Config::get_item('mymix_devices_dir') . $mac . "/profiles/" . $item_name;
				break;
			case "mymix-pref":
				$source = Config::get_item('mymix_devices_dir') . $mac . "/prefs";
				break;
			case "mymix-lock":
				$source = Config::get_item('mymix_devices_dir') . $mac . "/menulock/menulock_mgr";
				break;
			case "iex16-pref":
				$source = Config::get_item('iex16_devices_dir') . $mac . "/prefs";
				break;
			case "mymix-device":
				$source = tempnam("/tmp/", "export");
				create_tar(Config::get_item('mymix_devices_dir') . $mac . "/", $source);
				break;
			case "project":
				$source = tempnam("/tmp/", "export");
				$export_name .= Config::get_item('project_file_ext');
				create_tar(Config::get_item('active_project_dir') , $source);
				break;
			default:
				throw new Exception("Unknown export type");
				break;
		}

		// send file to browser
		$mimetype = mime_content_type($source);
		header("Content-Type: " . $mimetype);
		header("Content-Disposition: attachment; filename=\"" . $export_name . "\"");
		readfile($source);
		switch($export_type)
		{
			case "mymix-profile":
			case "project":
				// remove temporary archive
				unlink($source);
				break;
		}
	}

	$mac = Input::post('mac');
	$item_name = Input::post('item_name');
	$export_to = Input::post('export_to');
	$export_type = Input::post('export_type');
	$export_name = Input::post('export_name');

	if(!Validate::mac_address($mac) && $export_type != "project")
	{
		die("Invalid MAC address!");
	}
	if(empty($export_name))
	{
		die("No export_name specified!");
	}

	switch($export_to)
	{
		case "local":
			export_local($export_type, $mac, $item_name, $export_name);
			break;
		case "usb":
			export_usb($export_type, $mac, $item_name, $export_name);
			break;
		case "browser":
			export_browser($export_type, $mac, $item_name, $export_name);
			break;
		default:
			die("No export destination specified!");
			break;
	}

/* end of export.php */
