<?php

class FTP {
	private static $ftp_user_name = 'root';
	private static $ftp_user_pass = 'root';

	private static $last_connect_ip = "";
	private static $connection_id = FALSE;

	private static function connect_if_needed($ip_address)
	{
		if(self::$last_connect_ip != $ip_address)
		{
			if(self::$last_connect_ip != "")
			{
				ftp_close(self::$connection_id);
			}
			self::$connection_id = ftp_connect($ip_address);
			if(self::$connection_id === FALSE)
			{
				throw new Exception("FTP connection failure");
			}
			self::$last_connect_ip = $ip_address;
			$login_result = ftp_login(self::$connection_id, self::$ftp_user_name, self::$ftp_user_pass);
		}
	}

	private static function put_file($local_path, $ip_address, $remote_path)
	{
		self::connect_if_needed($ip_address);
		$success = ftp_put(self::$connection_id, $remote_path, $local_path, FTP_BINARY);
		if(!$success)
		{
			error_log("FTP file put failed".
				" IP: " . $ip_address .
				" local: " . $local_path .
				" remote: " . $remote_path);
		}
	}

	private static function get_file($local_path, $ip_address, $remote_path)
	{
		// create the local directory if it doesn't exist
		self::mkdir_if_needed(dirname($local_path));

		self::connect_if_needed($ip_address);
		$success = ftp_get(self::$connection_id, $local_path, $remote_path, FTP_BINARY);
		if(!$success)
		{
			error_log("FTP file get failed".
				" IP: " . $ip_address .
				" local: " . $local_path .
				" remote: " . $remote_path);
		}
	}

	private static function mkdir_if_needed($path)
	{
		if(!is_dir($path))
		{
			mkdir($path, 0777, TRUE);
		}
	}

	public static function push_mymix_profile($ip_address, $mac_address, $profile_name)
	{
		require_once("helpers/config.php");
		self::put_file(
			Config::get_item('mymix_devices_dir') . $mac_address . "/profiles/" . $profile_name,
			$ip_address,
			"/mnt/settings/profiles/" . $profile_name
		);
	}

	public static function pull_mymix_profile($ip_address, $mac_address, $profile_name)
	{
		require_once("helpers/config.php");
		self::get_file(
			Config::get_item('mymix_devices_dir') . $mac_address . "/profiles/" . $profile_name,
			$ip_address,
			"/mnt/settings/profiles/" . $profile_name
		);
	}

	public static function push_all_mymix_config($ip_address, $mac_address)
	{
		require_once("models/mymix_profile.php");

		// Push the profiles first, in case one was renamed or a new one created.
		$local_profiles = MyMix_Profile::get_profile_list($mac_address);
		foreach($local_profiles as $this_profile)
		{
			self::push_mymix_profile($ip_address, $mac_address, $this_profile);
		}

		// Push the preferences second, so that the current profile will be correct.
		self::push_mymix_preference($ip_address, $mac_address);

		// Lastly, delete any profiles that were deleted or renamed locally. This needs
		// to be done last so that we don't delete the MyMix's current profile.
		$remote_profiles = self::get_mymix_profile_list($ip_address);
		foreach($remote_profiles as $this_profile)
		{
			if(!in_array($this_profile, $local_profiles))
			{
				self::delete_mymix_profile($ip_address, $this_profile);
			}
		}

		// Push the lock settings last - order doesn't appear to be important for locks.
		self::push_mymix_lock($ip_address, $mac_address);
	}

	public static function pull_all_mymix_config($ip_address, $mac_address)
	{
		require_once("models/mymix_profile.php");

		// Pull the preferences
		self::pull_mymix_preference($ip_address, $mac_address);

		// Pull the profiles
		$remote_profiles = self::get_mymix_profile_list($ip_address);
		foreach($remote_profiles as $profile_name)
		{
			self::pull_mymix_profile($ip_address, $mac_address, $profile_name);
		}

		// Delete any local profiles that aren't on the myMix
		$local_profiles = MyMix_Profile::get_profile_list($mac_address);
		foreach($local_profiles as $this_profile)
		{
			if(!in_array($this_profile, $remote_profiles))
			{
				MyMix_Profile::delete_profile($mac_address, $this_profile);
			}
		}

		// Pull lock settings
		self::pull_mymix_lock($ip_address, $mac_address);
	}

	public static function push_iex16_profile($ip_address, $mac_address)
	{
		require_once("helpers/config.php");
		self::put_file(
			Config::get_item('iex16_devices_dir') . $mac_address . "/prefs",
			$ip_address,
			"/mnt/settings/prefs"
		);
	}

	public static function pull_iex16_profile($ip_address, $mac_address)
	{
		require_once("helpers/config.php");
		self::get_file(
			Config::get_item('iex16_devices_dir') . $mac_address . "/prefs",
			$ip_address,
			"/mnt/settings/prefs"
		);
	}

	public static function push_mymix_preference($ip_address, $mac_address)
	{
		require_once("helpers/config.php");
		self::put_file(
			Config::get_item('mymix_devices_dir') . $mac_address . "/prefs",
			$ip_address,
			"/mnt/settings/prefs"
		);
	}

	public static function pull_mymix_preference($ip_address, $mac_address)
	{
		require_once("helpers/config.php");
		self::get_file(
			Config::get_item('mymix_devices_dir') . $mac_address . "/prefs",
			$ip_address,
			"/mnt/settings/prefs"
		);
	}

	public static function get_mymix_profile_list($ip_address)
	{
		$retval = array();
		
		self::connect_if_needed($ip_address);
		$list = ftp_nlist(self::$connection_id, "/mnt/settings/profiles");
		if($list !== FALSE)
		{
			foreach($list as $this_profile)
			{
				$retval[] = basename($this_profile);
			}
		}

		return $retval;
	}

	public static function delete_mymix_profile($ip_address, $profile_name)
	{
		if(empty($ip_address) || empty($profile_name))
		{
			throw new Exception("Tried to delete a profile without an IP address or profile name!");
		}
		self::connect_if_needed($ip_address);
		ftp_delete(self::$connection_id, "/mnt/settings/profiles/" . $profile_name);
	}

	public static function rename_mymix_profile($ip_address, $old_profile_name, $new_profile_name)
	{
		if(empty($ip_address) || empty($old_profile_name) || empty($new_profile_name))
		{
			throw new Exception("Tried to rename a profile without an IP address or profile name!");
		}
		self::connect_if_needed($ip_address);
		ftp_rename(self::$connection_id,
			"/mnt/settings/profiles/" . $old_profile_name,
			"/mnt/settings/profiles/" . $new_profile_name);
	}

	public static function push_mymix_lock($ip_address, $mac_address)
	{
		require_once("helpers/config.php");
		self::put_file(
			Config::get_item('mymix_devices_dir') . $mac_address . "/menulock/menulock_mgr",
			$ip_address,
			"/mnt/settings/menulock/menulock_mgr"
		);
	}

	public static function pull_mymix_lock($ip_address, $mac_address)
	{
		require_once("helpers/config.php");
		$local_path = Config::get_item('mymix_devices_dir') . $mac_address . "/menulock/menulock_mgr";
		self::mkdir_if_needed(dirname($local_path));
		self::get_file($local_path, $ip_address, "/mnt/settings/menulock/menulock_mgr");
	}
}

/* End of ftp.php*/
