<?php

// Model to handle Avahi interactions
class Avahi {
	private static $encoded_chars = array(
		"\\032",
		"\\033",
		"\\034",
		"\\035",
		"\\036",
		"\\037",
		"\\038",
		"\\039",
		"\\040",
		"\\041",
		"\\042",
		"\\043",
		"\\044",
		"\\045",
		"\\046",
		"\\047",
		"\\048",
		"\\049",
		"\\050",
		"\\051",
		"\\052",
		"\\053",
		"\\054",
		"\\055",
		"\\056",
		"\\057",
		"\\058",
		"\\059",
		"\\060",
		"\\061",
		"\\062",
		"\\063",
		"\\064",
		"\\065",
		"\\066",
		"\\067",
		"\\068",
		"\\069",
		"\\070",
		"\\071",
		"\\072",
		"\\073",
		"\\074",
		"\\075",
		"\\076",
		"\\077",
		"\\078",
		"\\079",
		"\\080",
		"\\081",
		"\\082",
		"\\083",
		"\\084",
		"\\085",
		"\\086",
		"\\087",
		"\\088",
		"\\089",
		"\\090",
		"\\091",
		"\\092",
		"\\093",
		"\\094",
		"\\095",
		"\\096",
		"\\097",
		"\\098",
		"\\099",
		"\\100",
		"\\101",
		"\\102",
		"\\103",
		"\\104",
		"\\105",
		"\\106",
		"\\107",
		"\\108",
		"\\109",
		"\\110",
		"\\111",
		"\\112",
		"\\113",
		"\\114",
		"\\115",
		"\\116",
		"\\117",
		"\\118",
		"\\119",
		"\\120",
		"\\121",
		"\\122",
		"\\123",
		"\\124",
		"\\125",
		"\\126",
	);
	private static $decoded_chars = array(
		" ",
		"!",
		"\"",
		"#",
		"$",
		"%",
		"&",
		"'",
		"(",
		")",
		"*",
		"+",
		",",
		"-",
		".",
		"/",
		"0",
		"1",
		"2",
		"3",
		"4",
		"5",
		"6",
		"7",
		"8",
		"9",
		":",
		";",
		"<",
		"=",
		">",
		"?",
		"@",
		"A",
		"B",
		"C",
		"D",
		"E",
		"F",
		"G",
		"H",
		"I",
		"J",
		"K",
		"L",
		"M",
		"N",
		"O",
		"P",
		"Q",
		"R",
		"S",
		"T",
		"U",
		"V",
		"W",
		"X",
		"Y",
		"Z",
		"[",
		"\\",
		"]",
		"^",
		"_",
		"`",
		"a",
		"b",
		"c",
		"d",
		"e",
		"f",
		"g",
		"h",
		"i",
		"j",
		"k",
		"l",
		"m",
		"n",
		"o",
		"p",
		"q",
		"r",
		"s",
		"t",
		"u",
		"v",
		"w",
		"x",
		"y",
		"z",
		"{",
		"|",
		"}",
		"~",
	);

	// We only need to call avahi-browse once per page load, since it's very
	// unlikely that the devices on the network will change within that time.
	private static $device_cache = array();


	// Replaces Avahi escaped characters with their ACSII equivelents.
	private static function unescape($string)
	{
		return str_replace(self::$encoded_chars, self::$decoded_chars, $string);
	}

	private static function parse_txt_record($txt_record)
	{
		$retval = array();

		$state = "none";
		$name = "";
		$value = "";
		for($i = 0; $i < strlen($txt_record); $i++)
		{
			$char = $txt_record[$i];

			if($char == "\"" && $state == "none")
			{
				$state = "name";
				continue;
			}
			elseif($char == "=" && $state == "name")
			{
				$state = "value";
				continue;
			}
			elseif($char == "\"" && $state == "value")
			{
				$state = "none";
				$retval[$name] = $value;
				$name = "";
				$value = "";
				continue;
			}

			if($state == "name")
			{
				$name .= $char;
			}
			elseif($state == "value")
			{
				$value .= $char;
			}
		}

		return $retval;
	}

	// Device type is one of mymix, iex16 or all.
	// Returns an array of matching devices found on the network.
	public static function get_devices($device_type)
	{
		$retval = array();

		// for testing without MDNS capable devices
		if(FALSE)
		{
			return array(
				array('name' => 'Nathans MyMix', 'ip_address' => '169.254.67.208', 'mac' => '74:6b:82:00:02:28')
			);
		}

		// Field deffinitions for use with -p (parsable output)
		$ENTRY_TYPE_FIELD = 0; // + for new, - for lost, = for resolved
		$INTERFACE_FIELD = 1; // eth0, etc
		$IP_VERSION_FIELD = 2; // IPv4 or IPv6
		$SERVICE_NAME_FIELD = 3;
		$SERVICE_TYPE_FIELD = 4;
		$DOMAIN_FIELD = 5; // usually "local"
		$HOSTNAME_FIELD = 6;
		$IP_ADDRESS_FIELD = 7;
		$PORT_FIELD = 8;
		$TXT_FIELD = 9;
		$FIELD_COUNT = 10;

		// MDNS hostname uses mixed case, but calling code uses all lower case.
		if($device_type == "mymix")
		{
			$device_type = "myMix";
		}

		if(empty(self::$device_cache))
		{
			// -a = browse for all service types
			// -t = terminate after outputting a "more or less" complete list
			// -c = terminate after outputting cached list
			// -l = ignore local services
			// -k = don't look up service types
			// -p = parsable output (fields seperated by ";")
			// -r = resolve services (get more data about each service)
			$command = "avahi-browse -t -l -k -p -r _ftp._tcp";
		
			$output = shell_exec($command);

			// Cache the output so we don't have to wait for avahi-browse
			// twice in one page load.
			self::$device_cache = explode("\n", $output);
		}

		foreach(self::$device_cache as $this_line)
		{
			$fields = explode(";", $this_line);
			if(count($fields) == $FIELD_COUNT)
			{
				$txt_fields = self::parse_txt_record($fields[$TXT_FIELD]);
				if(empty($txt_fields['movek']))
				{
					continue;
				}

				// An equals sign in the first position means this is a resolved entry.
				if($fields[$ENTRY_TYPE_FIELD] == "=" && ($txt_fields['movek'] == $device_type || $device_type == "all"))
				{
					$mac_pos = strpos($fields[$HOSTNAME_FIELD], "-");
					$mac = "74:6b:82:"; // Movek MAC address
					$mac .= substr($fields[$HOSTNAME_FIELD], $mac_pos + 1, 2) . ":";
					$mac .= substr($fields[$HOSTNAME_FIELD], $mac_pos + 4, 2) . ":";
					$mac .= substr($fields[$HOSTNAME_FIELD], $mac_pos + 7, 2);

					$type = $txt_fields['movek'];
					if($type == "myMix")
					{
						$type = "mymix";
					}

					$new_entry = array(
						'name' => $txt_fields['name'], 
						'service_type' => $fields[$SERVICE_TYPE_FIELD],
						'ip_address' => $fields[$IP_ADDRESS_FIELD],
						'port' => $fields[$PORT_FIELD],
						'txt' => $fields[$TXT_FIELD],
						'mac' => $mac,
						'type' => $type,
					);
					$retval[] = $new_entry;
				}
			}
		}

		return $retval;
	}
}

/* End of avahi.php */
