<?php

// Model to handle interactions with MyMix lock files
class MyMix_Lock
{
	// default_xml is at the end of the file
	private $lock_data;
	private $lock_file_path;

	function __construct($mac)
	{
		require_once('helpers/config.php');
		$filename = Config::get_item('mymix_devices_dir') . $mac . "/menulock/menulock_mgr";
		if(file_exists($filename))
		{
			$this->load($filename);
		}
		else
		{
			$this->lock_data = new SimpleXMLElement($this->default_xml);
			$this->lock_file_path = $filename;
		}
	}

	private function load($filename)
	{
		libxml_use_internal_errors(true);
		$retval = simplexml_load_file($filename);
		if($retval === FALSE)
		{
			$errors = libxml_get_errors();
			$error_message = "";
			foreach ($errors as $error)
			{
				$error_message .= $error->message . " in " . $error->file . " at line " . $error->line . ".\n";
			}

			throw new Exception("Failed to open file: " . $error_message);
		}

		$this->lock_data = $retval;
		$this->lock_file_path = $filename;
	}

	public function save_as($filename)
	{
		require_once("helpers/filesystem.php");
		$path = dirname($filename);
		Filesystem::mkdir_if_needed($path);
		$result = file_put_contents($filename, $this->lock_data->saveXML());
		if($result === FALSE)
		{
			$error = error_get_last();
			throw new Exception("Failed to save file: " . $error['message']);
		}
	}

	public function save()
	{
		$this->save_as($this->lock_file_path);
	}

	private function bool_to_string($bool)
	{
		if($bool === TRUE || $bool == "true" || $bool == "1")
		{
			return "1";
		}
		else
		{
			return "0";
		}
	}

	private function find_node($start_node, $name)
	{
		if($start_node->name == $name)
		{
			return $start_node;
		}

		foreach($start_node->children() as $next_node)
		{
			$node = $this->find_node($next_node, $name);
			if(!empty($node))
			{
				return $node;
			}
		}

		return "";
	}

	// helpers for getting and setting locks
	private function set_lock_helper($screen, $mode, $control, $locked)
	{
		$screen_node = $this->find_node($this->lock_data, $screen);
		$mode_node = $this->find_node($screen_node, $mode);
		$control_node = $this->find_node($mode_node, $control);
		$control_node->locked = $this->bool_to_string($locked);
	}

	private function get_lock_helper($screen, $mode, $control)
	{
		$screen_node = $this->find_node($this->lock_data, $screen);
		$mode_node = $this->find_node($screen_node, $mode);
		$control_node = $this->find_node($mode_node, $control);
		return (string)$control_node->locked;
	}

	// getters and setters
	public function set_mute_button_lock($locked)
	{
		$global_keys = $this->lock_data->globalkeylist;
		$mute = $this->find_node($global_keys, "MUTE");
		$mute->locked = $this->bool_to_string($locked);
	}

	public function set_record_button_lock($locked)
	{
		$global_keys = $this->lock_data->globalkeylist;
		$record = $this->find_node($global_keys, "REC");
		$record->locked = $this->bool_to_string($locked);
	}

	public function set_global_lock($locked)
	{
		//$this->set_lock_helper("MainScreen", "eNormal", "MASTER VOLUME", $locked);
		$this->lock_data->globallock = $this->bool_to_string($locked);
	}

	public function get_global_lock()
	{
		return (string)$this->lock_data->globallock;
		//return $this->get_lock_helper("MainScreen", "eNormal", "MASTER VOLUME");
	}

	public function set_master_volume_lock($locked)
	{
		$this->set_lock_helper("MainScreen", "eNormal", "MASTER VOLUME", $locked);
	}

	public function get_master_volume_lock()
	{
		return $this->get_lock_helper("MainScreen", "eNormal", "MASTER VOLUME");
	}

	public function set_master_volume_zero_lock($locked)
	{
		$this->set_lock_helper("MainScreen", "eSelectAll", "ZERO MIX", $locked);
	}

	public function get_master_volume_zero_lock()
	{
		return $this->get_lock_helper("MainScreen", "eSelectAll", "ZERO MIX");
	}

	public function set_solo_lock($locked)
	{
		$this->set_lock_helper("MainScreen", "eNormal", "SOLO", $locked);
	}

	public function get_solo_lock()
	{
		return $this->get_lock_helper("MainScreen", "eNormal", "SOLO");
	}

	public function set_mute_lock($locked)
	{
		$this->set_lock_helper("MainScreen", "eNormal", "MUTE", $locked);
	}

	public function get_mute_lock()
	{
		return $this->get_lock_helper("MainScreen", "eNormal", "MUTE");
	}

	public function set_settings_lock($locked)
	{
		$this->set_lock_helper("MainScreen", "eNormal", "SETTINGS", $locked);
	}

	public function get_settings_lock()
	{
		return $this->get_lock_helper("MainScreen", "eNormal", "SETTINGS");
	}

	public function set_select_button_lock($locked)
	{
		$this->set_lock_helper("MainScreen", "eNormal", "SELECT", $locked);
	}

	public function get_select_button_lock()
	{
		return $this->get_lock_helper("MainScreen", "eNormal", "SELECT");
	}

	public function set_volume_lock($locked)
	{
		$this->set_lock_helper("MainScreen", "eEdit", "VOLUME", $locked);
		$this->set_lock_helper("MainScreen", "eEditStereo", "VOLUME", $locked);
	}

	public function get_volume_lock()
	{
		return $this->get_lock_helper("MainScreen", "eEdit", "VOLUME");
		return $this->get_lock_helper("MainScreen", "eEditStereo", "VOLUME");
	}

	public function set_tone_control_lock($locked)
	{
		$this->set_lock_helper("MainScreen", "eEdit", "TONE", $locked);
		$this->set_lock_helper("MainScreen", "eEditStereo", "TONE", $locked);
	}

	public function get_tone_control_lock()
	{
		return $this->get_lock_helper("MainScreen", "eEdit", "TONE");
		return $this->get_lock_helper("MainScreen", "eEditStereo", "TONE");
	}

	public function set_effect_send_lock($locked)
	{
		$this->set_lock_helper("MainScreen", "eEdit", "EFFECT", $locked);
		$this->set_lock_helper("MainScreen", "eEditStereo", "EFFECT", $locked);
	}

	public function get_effect_send_lock()
	{
		return $this->get_lock_helper("MainScreen", "eEdit", "EFFECT");
		return $this->get_lock_helper("MainScreen", "eEditStereo", "EFFECT");
	}

	public function set_pan_balance_lock($locked)
	{
		$this->set_lock_helper("MainScreen", "eEdit", "PAN", $locked);
		$this->set_lock_helper("MainScreen", "eEditStereo", "BALANCE", $locked);
	}

	public function get_pan_balance_lock()
	{
		return $this->get_lock_helper("MainScreen", "eEdit", "PAN");
		return $this->get_lock_helper("MainScreen", "eEditStereo", "BALANCE");
	}

	public function set_profiles_lock($locked)
	{
		$this->set_lock_helper("SettingsScreen", "eNormal", "Profiles", $locked);
	}

	public function get_profiles_lock()
	{
		return $this->get_lock_helper("SettingsScreen", "eNormal", "Profiles");
	}

	public function set_delete_profile_lock($locked)
	{
		$this->set_lock_helper("ProfileScreen", "eNormal", "DELETE", $locked);
	}

	public function get_delete_profile_lock()
	{
		return $this->get_lock_helper("ProfileScreen", "eNormal", "DELETE");
	}

	public function set_new_profile_lock($locked)
	{
		$this->set_lock_helper("ProfileScreen", "eNormal", "NEW", $locked);
	}

	public function get_new_profile_lock()
	{
		return $this->get_lock_helper("ProfileScreen", "eNormal", "NEW");
	}

	public function set_rename_profile_lock($locked)
	{
		$this->set_lock_helper("ProfileScreen", "eNormal", "RENAME", $locked);
	}

	public function get_rename_profile_lock()
	{
		return $this->get_lock_helper("ProfileScreen", "eNormal", "RENAME");
	}

	public function set_local_io_lock($locked)
	{
		$this->set_lock_helper("SettingsScreen", "eNormal", "Local Inputs/Outputs", $locked);
	}

	public function get_local_io_lock()
	{
		return $this->get_lock_helper("SettingsScreen", "eNormal", "Local Inputs/Outputs");
	}

	public function set_effects_lock($locked)
	{
		$this->set_lock_helper("SettingsScreen", "eNormal", "Effects", $locked);
	}

	public function get_effects_lock()
	{
		return $this->get_lock_helper("SettingsScreen", "eNormal", "Effects");
	}

	public function set_master_eq_lock($locked)
	{
		$this->set_lock_helper("SettingsScreen", "eNormal", "Master Equalizer", $locked);
	}

	public function get_master_eq_lock()
	{
		return $this->get_lock_helper("SettingsScreen", "eNormal", "Master Equalizer");
	}

	public function set_sessions_lock($locked)
	{
		$this->set_lock_helper("SettingsScreen", "eNormal", "Sessions", $locked);
	}

	public function get_sessions_lock()
	{
		return $this->get_lock_helper("SettingsScreen", "eNormal", "Sessions");
	}

	public function set_session_delete_lock($locked)
	{
		$this->set_lock_helper("SessionsScreen", "eNormal", "DELETE", $locked);
	}

	public function get_session_delete_lock()
	{
		return $this->get_lock_helper("SessionsScreen", "eNormal", "DELETE");
	}

	public function set_session_new_lock($locked)
	{
		$this->set_lock_helper("SessionsScreen", "eNormal", "NEW", $locked);
	}

	public function get_session_new_lock()
	{
		return $this->get_lock_helper("SessionsScreen", "eNormal", "NEW");
	}

	public function set_session_rename_lock($locked)
	{
		$this->set_lock_helper("SessionsScreen", "eNormal", "RENAME", $locked);
	}

	public function get_session_rename_lock()
	{
		return $this->get_lock_helper("SessionsScreen", "eNormal", "RENAME");
	}

	public function set_session_play_lock($locked)
	{
		$this->set_lock_helper("SessionsScreen", "eNormal", "PLAY", $locked);
	}

	public function get_session_play_lock()
	{
		return $this->get_lock_helper("SessionsScreen", "eNormal", "PLAY");
	}

	public function set_remote_devices_lock($locked)
	{
		$this->set_lock_helper("SettingsScreen", "eNormal", "Remote Devices", $locked);
	}

	public function get_remote_devices_lock()
	{
		return $this->get_lock_helper("SettingsScreen", "eNormal", "Remote Devices");
	}

	public function set_remote_channel_select_lock($locked)
	{
		$this->set_lock_helper("SettingsScreen", "eNormal", "Remote Channel Select", $locked);
	}

	public function get_remote_channel_select_lock()
	{
		return $this->get_lock_helper("SettingsScreen", "eNormal", "Remote Channel Select");
	}

	public function set_administration_lock($locked)
	{
		$this->set_lock_helper("SettingsScreen", "eNormal", "Administration", $locked);
	}

	public function get_administration_lock()
	{
		return $this->get_lock_helper("SettingsScreen", "eNormal", "Administration");
	}

	public function set_factory_default_lock($locked)
	{
		$this->set_lock_helper("AdministrationScreen", "eNormal", "Restore Factory Defaults", $locked);
		$this->set_lock_helper("AdministrationScreen", "eFormat", "Restore Factory Defaults", $locked);
	}

	public function get_factory_default_lock()
	{
		return $this->get_lock_helper("AdministrationScreen", "eNormal", "Restore Factory Defaults");
		//return $this->get_lock_helper("AdminScreen", "eFormat", "Restore Factory Defaults");
	}

	public function set_update_firmware_lock($locked)
	{
		$this->set_lock_helper("AdministrationScreen", "eNormal", "Update IEX16 Firmware", $locked);
		$this->set_lock_helper("AdministrationScreen", "eFormat", "Update IEX16 Firmware", $locked);
	}

	public function get_update_firmware_lock()
	{
		return $this->get_lock_helper("AdministrationScreen", "eNormal", "Update IEX16 Firmware");
		//return $this->get_lock_helper("AdminScreen", "eFormat", "Update IEX16 Firmware");
	}

	public function set_format_card_lock($locked)
	{
		$this->set_lock_helper("AdministrationScreen", "eNormal", "Format SD Card", $locked);
		$this->set_lock_helper("AdministrationScreen", "eFormat", "Format SD Card", $locked);
	}

	public function get_format_card_lock()
	{
		return $this->get_lock_helper("AdministrationScreen", "eNormal", "Format SD Card");
		// assume that both are locked if the normal one is locked
		//return $this->get_lock_helper("AdminScreen", "eFormat", "Format SD Card");
	}

	public function set_preferences_lock($locked)
	{
		$this->set_lock_helper("SettingsScreen", "eNormal", "Preferences", $locked);
	}

	public function get_preferences_lock()
	{
		return $this->get_lock_helper("SettingsScreen", "eNormal", "Preferences");
	}

	public function set_preferences_unit_name_lock($locked)
	{
		$this->set_lock_helper("PreferencesScreen", "ePrefsNormal", "Unit Name:", $locked);
	}

	public function get_preferences_unit_name_lock()
	{
		return $this->get_lock_helper("PreferencesScreen", "ePrefsNormal", "Unit Name:");
	}

	public function set_all($locked)
	{
		$locked_text = $this->bool_to_string($locked);

		// globalkeylist
		$this->lock_data->globalkeylist->key[0]->locked = $locked_text;
		$this->lock_data->globalkeylist->key[1]->locked = $locked_text;

		// epage 0
		$this->lock_data->epage[0]->locked = $locked_text;

		// epage 1
		$epage = $this->lock_data->epage[1];
		$epage->locked = $locked_text;

		$keylist = $epage->listview->mode[0]->keylist;
		$keylist->key[0]->locked = $locked_text;
		$keylist->key[1]->locked = $locked_text;
		$keylist->key[2]->locked = $locked_text;
		$keylist->key[3]->locked = $locked_text;
		$keylist->key[4]->locked = $locked_text;

		$keylist = $epage->listview->mode[1]->keylist;
		$keylist->key[0]->locked = $locked_text;
		$keylist->key[1]->locked = $locked_text;
		$keylist->key[2]->locked = $locked_text;
		$keylist->key[3]->locked = $locked_text;
		$keylist->key[4]->locked = $locked_text;

		$keylist = $epage->listview->mode[2]->keylist;
		$keylist->key[0]->locked = $locked_text;
		$keylist->key[1]->locked = $locked_text;
		$keylist->key[2]->locked = $locked_text;
		$keylist->key[3]->locked = $locked_text;
		$keylist->key[4]->locked = $locked_text;

		$keylist = $epage->listview->mode[3]->keylist;
		$keylist->key[0]->locked = $locked_text;
		$keylist->key[1]->locked = $locked_text;

		$keylist = $epage->listview->mode[4]->keylist;
		$keylist->key[0]->locked = $locked_text;
		$keylist->key[1]->locked = $locked_text;

		$epage->listview->mode[5]->keylist->key[0]->locked = $locked_text;

		// epage 2
		$epage = $this->lock_data->epage[2];
		$epage->locked = $locked_text;

		$keylist = $epage->listview->mode[0]->keylist;
		$keylist->key[0]->locked = $locked_text;
		$rowlist = $epage->listview->mode[0]->rowlist;
		$rowlist->row[0]->locked = $locked_text;
		$rowlist->row[1]->locked = $locked_text;
		$rowlist->row[2]->locked = $locked_text;
		$rowlist->row[3]->locked = $locked_text;
		$rowlist->row[4]->locked = $locked_text;
		$rowlist->row[5]->locked = $locked_text;
		$rowlist->row[6]->locked = $locked_text;
		$rowlist->row[7]->locked = $locked_text;
		$rowlist->row[8]->locked = $locked_text;

		$epage->listview->mode[1]->keylist->key[0]->locked = $locked_text;

		// epage 3
		$epage = $this->lock_data->epage[3];
		$epage->locked = $locked_text;

		$keylist = $epage->listview->mode[0]->keylist;
		$keylist->key[0]->locked = $locked_text;
		$keylist->key[1]->locked = $locked_text;
		$keylist->key[2]->locked = $locked_text;
		$keylist->key[3]->locked = $locked_text;
		$keylist->key[4]->locked = $locked_text;

		$keylist = $epage->listview->mode[1]->keylist;
		$keylist->key[0]->locked = $locked_text;
		$keylist->key[1]->locked = $locked_text;
		$keylist->key[2]->locked = $locked_text;
		$keylist->key[3]->locked = $locked_text;

		$keylist = $epage->listview->mode[2]->keylist;
		$keylist->key[0]->locked = $locked_text;

		$keylist = $epage->listview->mode[3]->keylist;
		$keylist->key[0]->locked = $locked_text;
		$keylist->key[1]->locked = $locked_text;

		// epage 4
		$epage = $this->lock_data->epage[4];
		$epage->locked = $locked_text;

		$keylist = $epage->listview->mode[0]->keylist;
		$keylist->key[0]->locked = $locked_text;
		$keylist->key[1]->locked = $locked_text;
		$rowlist = $epage->listview->mode[0]->rowlist;
		$rowlist->row[0]->locked = $locked_text;
		$rowlist->row[1]->locked = $locked_text;
		$rowlist->row[2]->locked = $locked_text;
		$rowlist->row[3]->locked = $locked_text;
		$rowlist->row[4]->locked = $locked_text;

		$keylist = $epage->listview->mode[1]->keylist;
		$keylist->key[0]->locked = $locked_text;
		$keylist->key[1]->locked = $locked_text;
		$rowlist = $epage->listview->mode[1]->rowlist;
		$rowlist->row[0]->locked = $locked_text;
		$rowlist->row[1]->locked = $locked_text;
		$rowlist->row[2]->locked = $locked_text;
		$rowlist->row[3]->locked = $locked_text;
		$rowlist->row[4]->locked = $locked_text;

		$keylist = $epage->listview->mode[2]->keylist;
		$keylist->key[0]->locked = $locked_text;

		$keylist = $epage->listview->mode[3]->keylist;
		$keylist->key[0]->locked = $locked_text;
		$keylist->key[1]->locked = $locked_text;
		$keylist->key[2]->locked = $locked_text;
		$keylist->key[3]->locked = $locked_text;

		$keylist = $epage->listview->mode[4]->keylist;
		$keylist->key[0]->locked = $locked_text;
		$keylist->key[1]->locked = $locked_text;
		$keylist->key[2]->locked = $locked_text;
		$keylist->key[3]->locked = $locked_text;

		$keylist = $epage->listview->mode[5]->keylist;
		$keylist->key[0]->locked = $locked_text;
		$keylist->key[1]->locked = $locked_text;
		$keylist->key[2]->locked = $locked_text;
		$keylist->key[3]->locked = $locked_text;

		$keylist = $epage->listview->mode[6]->keylist;
		$keylist->key[0]->locked = $locked_text;
		$keylist->key[1]->locked = $locked_text;
		$keylist->key[2]->locked = $locked_text;
		$keylist->key[3]->locked = $locked_text;

		$keylist = $epage->listview->mode[7]->keylist;
		$keylist->key[0]->locked = $locked_text;

		$keylist = $epage->listview->mode[8]->keylist;
		$keylist->key[0]->locked = $locked_text;

		// epage 5
		$epage = $this->lock_data->epage[5];
		$epage->locked = $locked_text;

		$keylist = $epage->listview->mode[0]->keylist;
		$keylist->key[0]->locked = $locked_text;
		$keylist->key[1]->locked = $locked_text;
		$rowlist = $epage->listview->mode[0]->rowlist;
		$rowlist->row[0]->locked = $locked_text;

		$keylist = $epage->listview->mode[1]->keylist;
		$keylist->key[0]->locked = $locked_text;
		$keylist->key[1]->locked = $locked_text;
		$rowlist = $epage->listview->mode[1]->rowlist;
		$rowlist->row[0]->locked = $locked_text;

		$keylist = $epage->listview->mode[2]->keylist;
		$keylist->key[0]->locked = $locked_text;
		$keylist->key[1]->locked = $locked_text;
		$rowlist = $epage->listview->mode[2]->rowlist;
		$rowlist->row[0]->locked = $locked_text;
		$rowlist->row[1]->locked = $locked_text;
		$rowlist->row[2]->locked = $locked_text;

		$keylist = $epage->listview->mode[3]->keylist;
		$keylist->key[0]->locked = $locked_text;
		$keylist->key[1]->locked = $locked_text;
		$rowlist = $epage->listview->mode[3]->rowlist;
		$rowlist->row[0]->locked = $locked_text;
		$rowlist->row[1]->locked = $locked_text;
		$rowlist->row[2]->locked = $locked_text;

		$keylist = $epage->listview->mode[4]->keylist;
		$keylist->key[0]->locked = $locked_text;

		// epage 6
		$epage = $this->lock_data->epage[6];
		$epage->locked = $locked_text;

		$keylist = $epage->listview->mode[0]->keylist;
		$keylist->key[0]->locked = $locked_text;
		$keylist->key[1]->locked = $locked_text;
		$keylist->key[2]->locked = $locked_text;
		$keylist->key[3]->locked = $locked_text;
		$keylist->key[4]->locked = $locked_text;
		$rowlist = $epage->listview->mode[0]->rowlist;
		$rowlist->row[0]->locked = $locked_text;
		$rowlist->row[1]->locked = $locked_text;
		$rowlist->row[2]->locked = $locked_text;
		$rowlist->row[3]->locked = $locked_text;

		$keylist = $epage->listview->mode[1]->keylist;
		$keylist->key[0]->locked = $locked_text;
		$keylist->key[1]->locked = $locked_text;
		$keylist->key[2]->locked = $locked_text;
		$keylist->key[3]->locked = $locked_text;

		$keylist = $epage->listview->mode[2]->keylist;
		$keylist->key[0]->locked = $locked_text;

		// epage 7
		$epage = $this->lock_data->epage[7];
		$epage->locked = $locked_text;

		$keylist = $epage->listview->mode[0]->keylist;
		$keylist->key[0]->locked = $locked_text;
		$keylist->key[1]->locked = $locked_text;
		$keylist->key[2]->locked = $locked_text;
		$keylist->key[3]->locked = $locked_text;
		$keylist->key[4]->locked = $locked_text;

		$keylist = $epage->listview->mode[1]->keylist;
		$keylist->key[0]->locked = $locked_text;
		$keylist->key[1]->locked = $locked_text;
		$keylist->key[2]->locked = $locked_text;
		$keylist->key[3]->locked = $locked_text;
		$keylist->key[4]->locked = $locked_text;

		$keylist = $epage->listview->mode[2]->keylist;
		$keylist->key[0]->locked = $locked_text;
		$keylist->key[1]->locked = $locked_text;
		$keylist->key[2]->locked = $locked_text;
		$keylist->key[3]->locked = $locked_text;

		$keylist = $epage->listview->mode[3]->keylist;
		$keylist->key[0]->locked = $locked_text;

		$keylist = $epage->listview->mode[4]->keylist;
		$keylist->key[0]->locked = $locked_text;
		$keylist->key[1]->locked = $locked_text;

		// nothing to lock for index 5

		$keylist = $epage->listview->mode[6]->keylist;
		$keylist->key[0]->locked = $locked_text;
		$keylist->key[1]->locked = $locked_text;
		$keylist->key[2]->locked = $locked_text;
		$keylist->key[3]->locked = $locked_text;
		$keylist->key[4]->locked = $locked_text;

		// epage 8
		$epage = $this->lock_data->epage[8];
		$epage->locked = $locked_text;

		$keylist = $epage->listview->mode[0]->keylist;
		$keylist->key[0]->locked = $locked_text;
		$keylist->key[1]->locked = $locked_text;

		$keylist = $epage->listview->mode[1]->keylist;
		$keylist->key[0]->locked = $locked_text;
		$keylist->key[1]->locked = $locked_text;

		// epage 9
		$epage = $this->lock_data->epage[9];
		$epage->locked = $locked_text;

		$keylist = $epage->listview->mode[0]->keylist;
		$keylist->key[0]->locked = $locked_text;
		$keylist->key[1]->locked = $locked_text;
		$keylist->key[2]->locked = $locked_text;
		$keylist->key[3]->locked = $locked_text;
		$keylist->key[4]->locked = $locked_text;

		$keylist = $epage->listview->mode[1]->keylist;
		$keylist->key[0]->locked = $locked_text;
		$keylist->key[1]->locked = $locked_text;
		$keylist->key[2]->locked = $locked_text;
		$keylist->key[3]->locked = $locked_text;

		$keylist = $epage->listview->mode[2]->keylist;
		$keylist->key[0]->locked = $locked_text;

		$keylist = $epage->listview->mode[3]->keylist;
		$keylist->key[0]->locked = $locked_text;
		$keylist->key[1]->locked = $locked_text;

		// epage 10
		$epage = $this->lock_data->epage[10];
		$epage->locked = $locked_text;

		$keylist = $epage->listview->mode[0]->keylist;
		$keylist->key[0]->locked = $locked_text;
		$keylist->key[1]->locked = $locked_text;
		$keylist->key[2]->locked = $locked_text;
		$keylist->key[3]->locked = $locked_text;
		$keylist->key[4]->locked = $locked_text;

		$keylist = $epage->listview->mode[1]->keylist;
		$keylist->key[0]->locked = $locked_text;
		$keylist->key[1]->locked = $locked_text;
		$keylist->key[2]->locked = $locked_text;
		$keylist->key[3]->locked = $locked_text;

		$keylist = $epage->listview->mode[2]->keylist;
		$keylist->key[0]->locked = $locked_text;

		$keylist = $epage->listview->mode[3]->keylist;
		$keylist->key[0]->locked = $locked_text;
		$keylist->key[1]->locked = $locked_text;

		// epage 11
		$epage = $this->lock_data->epage[11];
		$epage->locked = $locked_text;

		$keylist = $epage->listview->mode[0]->keylist;
		$keylist->key[0]->locked = $locked_text;
		$keylist->key[1]->locked = $locked_text;
		$rowlist = $epage->listview->mode[0]->rowlist;
		$rowlist->row[0]->locked = $locked_text;
		$rowlist->row[1]->locked = $locked_text;
		$rowlist->row[2]->locked = $locked_text;
		$rowlist->row[3]->locked = $locked_text;
		$rowlist->row[4]->locked = $locked_text;
		$rowlist->row[5]->locked = $locked_text;

		$keylist = $epage->listview->mode[1]->keylist;
		$keylist->key[0]->locked = $locked_text;

		$keylist = $epage->listview->mode[2]->keylist;
		$keylist->key[0]->locked = $locked_text;
		$keylist->key[1]->locked = $locked_text;

		$keylist = $epage->listview->mode[3]->keylist;
		$keylist->key[0]->locked = $locked_text;

		$keylist = $epage->listview->mode[4]->keylist;
		$keylist->key[0]->locked = $locked_text;
		$keylist->key[1]->locked = $locked_text;

		$keylist = $epage->listview->mode[5]->keylist;
		$keylist->key[0]->locked = $locked_text;

		$keylist = $epage->listview->mode[6]->keylist;
		$keylist->key[0]->locked = $locked_text;
		$keylist->key[1]->locked = $locked_text;
		$keylist->key[2]->locked = $locked_text;
		$keylist->key[3]->locked = $locked_text;

		$keylist = $epage->listview->mode[7]->keylist;
		$keylist->key[0]->locked = $locked_text;
		$keylist->key[1]->locked = $locked_text;
		$keylist->key[2]->locked = $locked_text;
		$keylist->key[3]->locked = $locked_text;

		$keylist = $epage->listview->mode[8]->keylist;
		$keylist->key[0]->locked = $locked_text;
		$keylist->key[1]->locked = $locked_text;
		$keylist->key[2]->locked = $locked_text;
		$keylist->key[3]->locked = $locked_text;

		$keylist = $epage->listview->mode[9]->keylist;
		$keylist->key[0]->locked = $locked_text;
		$keylist->key[1]->locked = $locked_text;
		$keylist->key[2]->locked = $locked_text;
		$keylist->key[3]->locked = $locked_text;

		$keylist = $epage->listview->mode[10]->keylist;
		$keylist->key[0]->locked = $locked_text;
		$keylist->key[1]->locked = $locked_text;
		$keylist->key[2]->locked = $locked_text;
		$keylist->key[3]->locked = $locked_text;

		$keylist = $epage->listview->mode[11]->keylist;
		$keylist->key[0]->locked = $locked_text;
		$keylist->key[1]->locked = $locked_text;
		$keylist->key[2]->locked = $locked_text;
		$keylist->key[3]->locked = $locked_text;

		$keylist = $epage->listview->mode[12]->keylist;
		$keylist->key[0]->locked = $locked_text;

		// epage 12
		$epage = $this->lock_data->epage[12];
		$epage->locked = $locked_text;

		$keylist = $epage->listview->mode[0]->keylist;
		$keylist->key[0]->locked = $locked_text;
		$keylist->key[1]->locked = $locked_text;
		$rowlist = $epage->listview->mode[0]->rowlist;
		$rowlist->row[0]->locked = $locked_text;
		$rowlist->row[1]->locked = $locked_text;
		$rowlist->row[2]->locked = $locked_text;
		$rowlist->row[3]->locked = $locked_text;

		$keylist = $epage->listview->mode[1]->keylist;
		$keylist->key[0]->locked = $locked_text;
		$keylist->key[1]->locked = $locked_text;
		$rowlist = $epage->listview->mode[1]->rowlist;
		$rowlist->row[0]->locked = $locked_text;
		$rowlist->row[1]->locked = $locked_text;
		$rowlist->row[2]->locked = $locked_text;
		$rowlist->row[3]->locked = $locked_text;

		// index 2 has nothing to lock

		$keylist = $epage->listview->mode[3]->keylist;
		$keylist->key[0]->locked = $locked_text;

		$keylist = $epage->listview->mode[4]->keylist;
		$keylist->key[0]->locked = $locked_text;

		$keylist = $epage->listview->mode[5]->keylist;
		$keylist->key[0]->locked = $locked_text;
		$keylist->key[1]->locked = $locked_text;

		$keylist = $epage->listview->mode[6]->keylist;
		$keylist->key[0]->locked = $locked_text;
		$keylist->key[1]->locked = $locked_text;

		$keylist = $epage->listview->mode[7]->keylist;
		$keylist->key[0]->locked = $locked_text;
		$keylist->key[1]->locked = $locked_text;

		$keylist = $epage->listview->mode[8]->keylist;
		$keylist->key[0]->locked = $locked_text;
		$keylist->key[1]->locked = $locked_text;

		$keylist = $epage->listview->mode[9]->keylist;
		$keylist->key[0]->locked = $locked_text;

		$keylist = $epage->listview->mode[10]->keylist;
		$keylist->key[0]->locked = $locked_text;
	}

	// Helper function for other lock list functions
	private static function lock_list_helper($folder)
	{
		$retval = array();

		$locks = array();
		if(is_dir($folder))
		{
			exec("ls " . $folder, $locks);
		}

		foreach($locks as $this_lock)
		{
			$retval[$this_lock] = $this_lock;
		}

		return $retval;
	}

	public static function get_local_saved_locks()
	{
		require_once("helpers/config.php");

		$path = Config::get_item('saved_mymix_locks_dir');
		return self::lock_list_helper($path);
	}

	public static function get_external_saved_locks()
	{
		require_once("helpers/config.php");

		$path = Config::get_item('external_mymix_locks_dir');
		return self::lock_list_helper($path);
	}

	public static function delete_local_saved_lock($lock_name)
	{
		$path = Config::get_item('saved_mymix_locks_dir') . $lock_name;
		unlink($path);
	}

	// putting this last in the file because it's so large
	private $default_xml = <<<XML
<?xml version="1.0" encoding="iso-8859-1"?>
<locks>
    <globallock>0</globallock>
    <globalkeylist>
        <key index="0">
            <id>77</id>
            <name>MUTE</name>
            <locked>0</locked>
        </key>
        <key index="1">
            <id>82</id>
            <name>REC</name>
            <locked>0</locked>
        </key>
    </globalkeylist>
    <pagelist>
        <page index="0">
            <name>MainScreen</name>
            <locked>0</locked>
            <modelist>
                <mode index="0">
                    <name>eNormal</name>
                    <keylist>
                        <key index="0">
                            <id>49</id>
                            <name>MASTER VOLUME</name>
                            <locked>0</locked>
                        </key>
                        <key index="1">
                            <id>50</id>
                            <name>SOLO</name>
                            <locked>0</locked>
                        </key>
                        <key index="2">
                            <id>51</id>
                            <name>MUTE</name>
                            <locked>0</locked>
                        </key>
                        <key index="3">
                            <id>52</id>
                            <name>SETTINGS</name>
                            <locked>0</locked>
                        </key>
                        <key index="4">
                            <id>32</id>
                            <name>SELECT</name>
                            <locked>0</locked>
                        </key>
                    </keylist>
                </mode>
                <mode index="1">
                    <name>eEdit</name>
                    <keylist>
                        <key index="0">
                            <id>49</id>
                            <name>VOLUME</name>
                            <locked>0</locked>
                        </key>
                        <key index="1">
                            <id>50</id>
                            <name>TONE</name>
                            <locked>0</locked>
                        </key>
                        <key index="2">
                            <id>51</id>
                            <name>EFFECT</name>
                            <locked>0</locked>
                        </key>
                        <key index="3">
                            <id>52</id>
                            <name>PAN</name>
                            <locked>0</locked>
                        </key>
                        <key index="4">
                            <id>32</id>
                            <name>SELECT</name>
                            <locked>0</locked>
                        </key>
                    </keylist>
                </mode>
                <mode index="2">
                    <name>eEditStereo</name>
                    <keylist>
                        <key index="0">
                            <id>49</id>
                            <name>VOLUME</name>
                            <locked>0</locked>
                        </key>
                        <key index="1">
                            <id>50</id>
                            <name>TONE</name>
                            <locked>0</locked>
                        </key>
                        <key index="2">
                            <id>51</id>
                            <name>EFFECT</name>
                            <locked>0</locked>
                        </key>
                        <key index="3">
                            <id>52</id>
                            <name>BALANCE</name>
                            <locked>0</locked>
                        </key>
                        <key index="4">
                            <id>32</id>
                            <name>SELECT</name>
                            <locked>0</locked>
                        </key>
                    </keylist>
                </mode>
                <mode index="3">
                    <name>eSelectAll</name>
                    <keylist>
                        <key index="0">
                            <id>49</id>
                            <name>BACK</name>
                            <locked>0</locked>
                        </key>
                        <key index="1">
                            <id>50</id>
                            <name>ZERO MIX</name>
                            <locked>0</locked>
                        </key>
                    </keylist>
                </mode>
                <mode index="4">
                    <name>eConfirm</name>
                    <keylist>
                        <key index="0">
                            <id>49</id>
                            <name>YES</name>
                            <locked>0</locked>
                        </key>
                        <key index="1">
                            <id>50</id>
                            <name>NO</name>
                            <locked>0</locked>
                        </key>
                    </keylist>
                </mode>
                <mode index="5">
                    <name>eMessage</name>
                    <keylist>
                        <key index="0">
                            <id>49</id>
                            <name>OK</name>
                            <locked>0</locked>
                        </key>
                    </keylist>
                </mode>
            </modelist>
        </page>
        <page index="1">
            <name>SettingsScreen</name>
            <locked>0</locked>
            <modelist>
                <mode index="0">
                    <name>eNormal</name>
                    <keylist>
                        <key index="0">
                            <id>49</id>
                            <name>BACK</name>
                            <locked>0</locked>
                        </key>
                    </keylist>
                    <rowlist>
                        <row index="0">
                            <name>Profiles</name>
                            <locked>0</locked>
                        </row>
                        <row index="1">
                            <name>Local Inputs/Outputs</name>
                            <locked>0</locked>
                        </row>
                        <row index="2">
                            <name>Effects</name>
                            <locked>0</locked>
                        </row>
                        <row index="3">
                            <name>Master Equalizer</name>
                            <locked>0</locked>
                        </row>
                        <row index="4">
                            <name>Sessions</name>
                            <locked>0</locked>
                        </row>
                        <row index="5">
                            <name>Remote Channel Select</name>
                            <locked>0</locked>
                        </row>
                        <row index="6">
                            <name>Remote Devices</name>
                            <locked>0</locked>
                        </row>
                        <row index="7">
                            <name>Preferences</name>
                            <locked>0</locked>
                        </row>
                        <row index="8">
                            <name>Administration</name>
                            <locked>0</locked>
                        </row>
                    </rowlist>
                </mode>
                <mode index="1">
                    <name>eMessage</name>
                    <keylist>
                        <key index="0">
                            <id>49</id>
                            <name>OK</name>
                            <locked>0</locked>
                        </key>
                    </keylist>
                </mode>
            </modelist>
        </page>
        <page index="2">
            <name>ProfileScreen</name>
            <locked>0</locked>
            <modelist>
                <mode index="0">
                    <name>eNormal</name>
                    <keylist>
                        <key index="0">
                            <id>49</id>
                            <name>BACK</name>
                            <locked>0</locked>
                        </key>
                        <key index="1">
                            <id>50</id>
                            <name>NEW</name>
                            <locked>0</locked>
                        </key>
                        <key index="2">
                            <id>51</id>
                            <name>DELETE</name>
                            <locked>0</locked>
                        </key>
                        <key index="3">
                            <id>52</id>
                            <name>RENAME</name>
                            <locked>0</locked>
                        </key>
                        <key index="4">
                            <id>32</id>
                            <name>SELECT</name>
                            <locked>0</locked>
                        </key>
                    </keylist>
                </mode>
                <mode index="1">
                    <name>eRename</name>
                    <keylist>
                        <key index="0">
                            <id>49</id>
                            <name>CANCEL</name>
                            <locked>0</locked>
                        </key>
                        <key index="1">
                            <id>50</id>
                            <name>CHANGE CASE</name>
                            <locked>0</locked>
                        </key>
                        <key index="2">
                            <id>51</id>
                            <name>CLEAR</name>
                            <locked>0</locked>
                        </key>
                        <key index="3">
                            <id>52</id>
                            <name>SAVE</name>
                            <locked>0</locked>
                        </key>
                    </keylist>
                </mode>
                <mode index="2">
                    <name>eMessage</name>
                    <keylist>
                        <key index="0">
                            <id>49</id>
                            <name>OK</name>
                            <locked>0</locked>
                        </key>
                    </keylist>
                </mode>
                <mode index="3">
                    <name>eConfirm</name>
                    <keylist>
                        <key index="0">
                            <id>49</id>
                            <name>YES</name>
                            <locked>0</locked>
                        </key>
                        <key index="1">
                            <id>50</id>
                            <name>NO</name>
                            <locked>0</locked>
                        </key>
                    </keylist>
                </mode>
            </modelist>
        </page>
        <page index="3">
            <name>InputsScreen</name>
            <locked>0</locked>
            <modelist>
                <mode index="0">
                    <name>eInputsNormal</name>
                    <keylist>
                        <key index="0">
                            <id>49</id>
                            <name>BACK</name>
                            <locked>0</locked>
                        </key>
                        <key index="1">
                            <id>32</id>
                            <name>SELECT</name>
                            <locked>0</locked>
                        </key>
                    </keylist>
                    <rowlist>
                        <row index="0">
                            <name>Phantom Power:</name>
                            <locked>0</locked>
                        </row>
                        <row index="1">
                            <name>Input Mode:</name>
                            <locked>0</locked>
                        </row>
                        <row index="2">
                            <name>Send Mix to Network:</name>
                            <locked>0</locked>
                        </row>
                        <row index="3">
                            <name>Input 1 Name:</name>
                            <locked>0</locked>
                        </row>
                        <row index="4">
                            <name>Input 2 Name:</name>
                            <locked>0</locked>
                        </row>
                    </rowlist>
                </mode>
                <mode index="1">
                    <name>eInputsModeEdit</name>
                    <keylist>
                        <key index="0">
                            <id>49</id>
                            <name>BACK</name>
                            <locked>0</locked>
                        </key>
                        <key index="1">
                            <id>32</id>
                            <name>SELECT</name>
                            <locked>0</locked>
                        </key>
                    </keylist>
                    <rowlist>
                        <row index="0">
                            <name>Phantom Power:</name>
                            <locked>0</locked>
                        </row>
                        <row index="1">
                            <name>Input Mode:</name>
                            <locked>0</locked>
                        </row>
                        <row index="2">
                            <name>Send Mix to Network:</name>
                            <locked>0</locked>
                        </row>
                        <row index="3">
                            <name>Input 1 Name:</name>
                            <locked>0</locked>
                        </row>
                        <row index="4">
                            <name>Input 2 Name:</name>
                            <locked>0</locked>
                        </row>
                    </rowlist>
                </mode>
                <mode index="2">
                    <name>eInputsModeEditFB</name>
                    <keylist>
                        <key index="0">
                            <id>49</id>
                            <name>DONE</name>
                            <locked>0</locked>
                        </key>
                    </keylist>
                </mode>
                <mode index="3">
                    <name>eChannel1Edit</name>
                    <keylist>
                        <key index="0">
                            <id>49</id>
                            <name>CANCEL</name>
                            <locked>0</locked>
                        </key>
                        <key index="1">
                            <id>50</id>
                            <name>CHANGE CASE</name>
                            <locked>0</locked>
                        </key>
                        <key index="2">
                            <id>51</id>
                            <name>CLEAR</name>
                            <locked>0</locked>
                        </key>
                        <key index="3">
                            <id>52</id>
                            <name>SAVE</name>
                            <locked>0</locked>
                        </key>
                    </keylist>
                </mode>
                <mode index="4">
                    <name>eChannel1EditFB</name>
                    <keylist>
                        <key index="0">
                            <id>49</id>
                            <name>CANCEL</name>
                            <locked>0</locked>
                        </key>
                        <key index="1">
                            <id>50</id>
                            <name>CHANGE CASE</name>
                            <locked>0</locked>
                        </key>
                        <key index="2">
                            <id>51</id>
                            <name>CLEAR</name>
                            <locked>0</locked>
                        </key>
                        <key index="3">
                            <id>52</id>
                            <name>SAVE</name>
                            <locked>0</locked>
                        </key>
                    </keylist>
                </mode>
                <mode index="5">
                    <name>eChannel2Edit</name>
                    <keylist>
                        <key index="0">
                            <id>49</id>
                            <name>CANCEL</name>
                            <locked>0</locked>
                        </key>
                        <key index="1">
                            <id>50</id>
                            <name>CHANGE CASE</name>
                            <locked>0</locked>
                        </key>
                        <key index="2">
                            <id>51</id>
                            <name>CLEAR</name>
                            <locked>0</locked>
                        </key>
                        <key index="3">
                            <id>52</id>
                            <name>SAVE</name>
                            <locked>0</locked>
                        </key>
                    </keylist>
                </mode>
                <mode index="6">
                    <name>eChannel2EditFB</name>
                    <keylist>
                        <key index="0">
                            <id>49</id>
                            <name>CANCEL</name>
                            <locked>0</locked>
                        </key>
                        <key index="1">
                            <id>50</id>
                            <name>CHANGE CASE</name>
                            <locked>0</locked>
                        </key>
                        <key index="2">
                            <id>51</id>
                            <name>CLEAR</name>
                            <locked>0</locked>
                        </key>
                        <key index="3">
                            <id>52</id>
                            <name>SAVE</name>
                            <locked>0</locked>
                        </key>
                    </keylist>
                </mode>
                <mode index="7">
                    <name>eFirstBoot</name>
                    <keylist>
                        <key index="0">
                            <id>49</id>
                            <name>DONE</name>
                            <locked>0</locked>
                        </key>
                    </keylist>
                </mode>
                <mode index="8">
                    <name>eMessage</name>
                    <keylist>
                        <key index="0">
                            <id>49</id>
                            <name>OK</name>
                            <locked>0</locked>
                        </key>
                    </keylist>
                </mode>
            </modelist>
        </page>
        <page index="4">
            <name>EffectsScreen</name>
            <locked>0</locked>
            <modelist>
                <mode index="0">
                    <name>eNormal</name>
                    <keylist>
                        <key index="0">
                            <id>49</id>
                            <name>BACK</name>
                            <locked>0</locked>
                        </key>
                        <key index="1">
                            <id>32</id>
                            <name>SELECT</name>
                            <locked>0</locked>
                        </key>
                    </keylist>
                    <rowlist>
                        <row index="0">
                            <name>Effect Type:</name>
                            <locked>0</locked>
                        </row>
                    </rowlist>
                </mode>
                <mode index="1">
                    <name>eSelectEffect</name>
                    <keylist>
                        <key index="0">
                            <id>49</id>
                            <name>BACK</name>
                            <locked>0</locked>
                        </key>
                        <key index="1">
                            <id>32</id>
                            <name>SELECT</name>
                            <locked>0</locked>
                        </key>
                    </keylist>
                    <rowlist>
                        <row index="0">
                            <name>Effect Type:</name>
                            <locked>0</locked>
                        </row>
                    </rowlist>
                </mode>
                <mode index="2">
                    <name>eDelayTimeEdit</name>
                    <keylist>
                        <key index="0">
                            <id>49</id>
                            <name>BACK</name>
                            <locked>0</locked>
                        </key>
                        <key index="1">
                            <id>32</id>
                            <name>SELECT</name>
                            <locked>0</locked>
                        </key>
                    </keylist>
                    <rowlist>
                        <row index="0">
                            <name>Effect Type:</name>
                            <locked>0</locked>
                        </row>
                        <row index="1">
                            <name>Time:</name>
                            <locked>0</locked>
                        </row>
                        <row index="2">
                            <name>Repeats:</name>
                            <locked>0</locked>
                        </row>
                    </rowlist>
                </mode>
                <mode index="3">
                    <name>eDelayRepeatsEdit</name>
                    <keylist>
                        <key index="0">
                            <id>49</id>
                            <name>BACK</name>
                            <locked>0</locked>
                        </key>
                        <key index="1">
                            <id>32</id>
                            <name>SELECT</name>
                            <locked>0</locked>
                        </key>
                    </keylist>
                    <rowlist>
                        <row index="0">
                            <name>Effect Type:</name>
                            <locked>0</locked>
                        </row>
                        <row index="1">
                            <name>Time:</name>
                            <locked>0</locked>
                        </row>
                        <row index="2">
                            <name>Repeats:</name>
                            <locked>0</locked>
                        </row>
                    </rowlist>
                </mode>
                <mode index="4">
                    <name>eMessage</name>
                    <keylist>
                        <key index="0">
                            <id>49</id>
                            <name>OK</name>
                            <locked>0</locked>
                        </key>
                    </keylist>
                </mode>
            </modelist>
        </page>
        <page index="5">
            <name>MasterEQScreen</name>
            <locked>0</locked>
            <modelist>
                <mode index="0">
                    <name>eNormal</name>
                    <keylist>
                        <key index="0">
                            <id>49</id>
                            <name>BACK</name>
                            <locked>0</locked>
                        </key>
                        <key index="1">
                            <id>50</id>
                            <name>LOW SHELF</name>
                            <locked>0</locked>
                        </key>
                        <key index="2">
                            <id>51</id>
                            <name>HIGH SHELF</name>
                            <locked>0</locked>
                        </key>
                        <key index="3">
                            <id>52</id>
                            <name>BYPASS</name>
                            <locked>0</locked>
                        </key>
                        <key index="4">
                            <id>32</id>
                            <name>SELECT</name>
                            <locked>0</locked>
                        </key>
                    </keylist>
                    <rowlist>
                        <row index="0">
                            <name>Low</name>
                            <locked>0</locked>
                        </row>
                        <row index="1">
                            <name>Low-Mid</name>
                            <locked>0</locked>
                        </row>
                        <row index="2">
                            <name>High-Mid</name>
                            <locked>0</locked>
                        </row>
                        <row index="3">
                            <name>High</name>
                            <locked>0</locked>
                        </row>
                    </rowlist>
                </mode>
                <mode index="1">
                    <name>eEdit</name>
                    <keylist>
                        <key index="0">
                            <id>49</id>
                            <name>FREQUENCY</name>
                            <locked>0</locked>
                        </key>
                        <key index="1">
                            <id>50</id>
                            <name>GAIN</name>
                            <locked>0</locked>
                        </key>
                        <key index="2">
                            <id>51</id>
                            <name>Q</name>
                            <locked>0</locked>
                        </key>
                        <key index="3">
                            <id>32</id>
                            <name>SELECT</name>
                            <locked>0</locked>
                        </key>
                    </keylist>
                </mode>
                <mode index="2">
                    <name>eMessage</name>
                    <keylist>
                        <key index="0">
                            <id>49</id>
                            <name>OK</name>
                            <locked>0</locked>
                        </key>
                    </keylist>
                </mode>
            </modelist>
        </page>
        <page index="6">
            <name>SessionsScreen</name>
            <locked>0</locked>
            <modelist>
                <mode index="0">
                    <name>eNormal</name>
                    <keylist>
                        <key index="0">
                            <id>49</id>
                            <name>BACK</name>
                            <locked>0</locked>
                        </key>
                        <key index="1">
                            <id>50</id>
                            <name>DELETE</name>
                            <locked>0</locked>
                        </key>
                        <key index="2">
                            <id>51</id>
                            <name>PLAY</name>
                            <locked>0</locked>
                        </key>
                        <key index="3">
                            <id>52</id>
                            <name>RENAME</name>
                            <locked>0</locked>
                        </key>
                        <key index="4">
                            <id>32</id>
                            <name>SELECT</name>
                            <locked>0</locked>
                        </key>
                    </keylist>
                </mode>
                <mode index="1">
                    <name>ePlay</name>
                    <keylist>
                        <key index="0">
                            <id>49</id>
                            <name>BACK</name>
                            <locked>0</locked>
                        </key>
                        <key index="1">
                            <id>50</id>
                            <name>PLAY ALONG</name>
                            <locked>0</locked>
                        </key>
                        <key index="2">
                            <id>51</id>
                            <name>STOP</name>
                            <locked>0</locked>
                        </key>
                        <key index="3">
                            <id>52</id>
                            <name>MORE</name>
                            <locked>0</locked>
                        </key>
                        <key index="4">
                            <id>32</id>
                            <name>SELECT</name>
                            <locked>0</locked>
                        </key>
                    </keylist>
                </mode>
                <mode index="2">
                    <name>eRename</name>
                    <keylist>
                        <key index="0">
                            <id>49</id>
                            <name>CANCEL</name>
                            <locked>0</locked>
                        </key>
                        <key index="1">
                            <id>50</id>
                            <name>CHANGE CASE</name>
                            <locked>0</locked>
                        </key>
                        <key index="2">
                            <id>51</id>
                            <name>CLEAR</name>
                            <locked>0</locked>
                        </key>
                        <key index="3">
                            <id>52</id>
                            <name>SAVE</name>
                            <locked>0</locked>
                        </key>
                    </keylist>
                </mode>
                <mode index="3">
                    <name>eMessage</name>
                    <keylist>
                        <key index="0">
                            <id>49</id>
                            <name>OK</name>
                            <locked>0</locked>
                        </key>
                    </keylist>
                </mode>
                <mode index="4">
                    <name>eConfirm</name>
                    <keylist>
                        <key index="0">
                            <id>49</id>
                            <name>YES</name>
                            <locked>0</locked>
                        </key>
                        <key index="1">
                            <id>50</id>
                            <name>NO</name>
                            <locked>0</locked>
                        </key>
                    </keylist>
                </mode>
                <mode index="5">
                    <name>eDeleting</name>
                </mode>
                <mode index="6">
                    <name>ePlayMore</name>
                    <keylist>
                        <key index="0">
                            <id>49</id>
                            <name>LOOP</name>
                            <locked>0</locked>
                        </key>
                        <key index="1">
                            <id>50</id>
                            <name>Mark 1</name>
                            <locked>0</locked>
                        </key>
                        <key index="2">
                            <id>51</id>
                            <name>Mark 2</name>
                            <locked>0</locked>
                        </key>
                        <key index="3">
                            <id>52</id>
                            <name>MORE</name>
                            <locked>0</locked>
                        </key>
                        <key index="4">
                            <id>32</id>
                            <name>SELECT</name>
                            <locked>0</locked>
                        </key>
                    </keylist>
                </mode>
            </modelist>
        </page>
        <page index="7">
            <name>RemoteChannelCfgScreen</name>
            <locked>0</locked>
            <modelist>
                <mode index="0">
                    <name>eNormal</name>
                    <keylist>
                        <key index="0">
                            <id>49</id>
                            <name>BACK</name>
                            <locked>0</locked>
                        </key>
                        <key index="1">
                            <id>32</id>
                            <name>SELECT</name>
                            <locked>0</locked>
                        </key>
                    </keylist>
                </mode>
                <mode index="1">
                    <name>eMessage</name>
                    <keylist>
                        <key index="0">
                            <id>49</id>
                            <name>OK</name>
                            <locked>0</locked>
                        </key>
                        <key index="1">
                            <id>32</id>
                            <name>SELECT</name>
                            <locked>0</locked>
                        </key>
                    </keylist>
                </mode>
            </modelist>
        </page>
        <page index="8">
            <name>RemoteDevicesScreen</name>
            <locked>0</locked>
            <modelist>
                <mode index="0">
                    <name>eNormal</name>
                    <keylist>
                        <key index="0">
                            <id>49</id>
                            <name>BACK</name>
                            <locked>0</locked>
                        </key>
                        <key index="1">
                            <id>50</id>
                            <name>RENAME</name>
                            <locked>0</locked>
                        </key>
                        <key index="2">
                            <id>51</id>
                            <name>LOCK</name>
                            <locked>0</locked>
                        </key>
                        <key index="3">
                            <id>52</id>
                            <name>FACTOR DEFAULT</name>
                            <locked>0</locked>
                        </key>
                        <key index="4">
                            <id>32</id>
                            <name>SELECT</name>
                            <locked>0</locked>
                        </key>
                    </keylist>
                </mode>
                <mode index="1">
                    <name>eRename</name>
                    <keylist>
                        <key index="0">
                            <id>49</id>
                            <name>CANCEL</name>
                            <locked>0</locked>
                        </key>
                        <key index="1">
                            <id>50</id>
                            <name>CHANGE CASE</name>
                            <locked>0</locked>
                        </key>
                        <key index="2">
                            <id>51</id>
                            <name>CLEAR</name>
                            <locked>0</locked>
                        </key>
                        <key index="3">
                            <id>52</id>
                            <name>SAVE</name>
                            <locked>0</locked>
                        </key>
                    </keylist>
                </mode>
                <mode index="2">
                    <name>eMessage</name>
                    <keylist>
                        <key index="0">
                            <id>49</id>
                            <name>OK</name>
                            <locked>0</locked>
                        </key>
                    </keylist>
                </mode>
                <mode index="3">
                    <name>eConfirm</name>
                    <keylist>
                        <key index="0">
                            <id>49</id>
                            <name>YES</name>
                            <locked>0</locked>
                        </key>
                        <key index="1">
                            <id>50</id>
                            <name>NO</name>
                            <locked>0</locked>
                        </key>
                    </keylist>
                </mode>
            </modelist>
        </page>
        <page index="9">
            <name>IEX16LScreen</name>
            <locked>0</locked>
            <modelist>
                <mode index="0">
                    <name>eNormal</name>
                    <keylist>
                        <key index="0">
                            <id>49</id>
                            <name>BACK</name>
                            <locked>0</locked>
                        </key>
                        <key index="1">
                            <id>50</id>
                            <name>RENAME</name>
                            <locked>0</locked>
                        </key>
                        <key index="2">
                            <id>51</id>
                            <name>MODE</name>
                            <locked>0</locked>
                        </key>
                        <key index="3">
                            <id>52</id>
                            <name>Gain</name>
                            <locked>0</locked>
                        </key>
                        <key index="4">
                            <id>32</id>
                            <name>SELECT</name>
                            <locked>0</locked>
                        </key>
                    </keylist>
                </mode>
                <mode index="1">
                    <name>eRename</name>
                    <keylist>
                        <key index="0">
                            <id>49</id>
                            <name>CANCEL</name>
                            <locked>0</locked>
                        </key>
                        <key index="1">
                            <id>50</id>
                            <name>CHANGE CASE</name>
                            <locked>0</locked>
                        </key>
                        <key index="2">
                            <id>51</id>
                            <name>CLEAR</name>
                            <locked>0</locked>
                        </key>
                        <key index="3">
                            <id>52</id>
                            <name>SAVE</name>
                            <locked>0</locked>
                        </key>
                    </keylist>
                </mode>
                <mode index="2">
                    <name>eMessage</name>
                    <keylist>
                        <key index="0">
                            <id>49</id>
                            <name>OK</name>
                            <locked>0</locked>
                        </key>
                    </keylist>
                </mode>
                <mode index="3">
                    <name>eConfirm</name>
                    <keylist>
                        <key index="0">
                            <id>49</id>
                            <name>YES</name>
                            <locked>0</locked>
                        </key>
                        <key index="1">
                            <id>50</id>
                            <name>NO</name>
                            <locked>0</locked>
                        </key>
                    </keylist>
                </mode>
            </modelist>
        </page>
        <page index="10">
            <name>PreferencesScreen</name>
            <locked>0</locked>
            <modelist>
                <mode index="0">
                    <name>ePrefsNormal</name>
                    <keylist>
                        <key index="0">
                            <id>49</id>
                            <name>BACK</name>
                            <locked>0</locked>
                        </key>
                        <key index="1">
                            <id>32</id>
                            <name>SELECT</name>
                            <locked>0</locked>
                        </key>
                    </keylist>
                    <rowlist>
                        <row index="0">
                            <name>Unit Name:</name>
                            <locked>0</locked>
                        </row>
                        <row index="1">
                            <name>Activity Timeout:</name>
                            <locked>0</locked>
                        </row>
                        <row index="2">
                            <name>Brightness:</name>
                            <locked>0</locked>
                        </row>
                        <row index="3">
                            <name>Date:</name>
                            <locked>0</locked>
                        </row>
                        <row index="4">
                            <name>Time:</name>
                            <locked>0</locked>
                        </row>
                        <row index="5">
                            <name>View:</name>
                            <locked>0</locked>
                        </row>
                    </rowlist>
                </mode>
                <mode index="1">
                    <name>eFirstBoot</name>
                    <keylist>
                        <key index="0">
                            <id>49</id>
                            <name>DONE</name>
                            <locked>0</locked>
                        </key>
                    </keylist>
                </mode>
                <mode index="2">
                    <name>eBrightnessChange</name>
                    <keylist>
                        <key index="0">
                            <id>49</id>
                            <name>BACK</name>
                            <locked>0</locked>
                        </key>
                        <key index="1">
                            <id>32</id>
                            <name>SELECT</name>
                            <locked>0</locked>
                        </key>
                    </keylist>
                </mode>
                <mode index="3">
                    <name>eBrightnessChangeFB</name>
                    <keylist>
                        <key index="0">
                            <id>49</id>
                            <name>DONE</name>
                            <locked>0</locked>
                        </key>
                    </keylist>
                </mode>
                <mode index="4">
                    <name>eTimeoutChange</name>
                    <keylist>
                        <key index="0">
                            <id>49</id>
                            <name>BACK</name>
                            <locked>0</locked>
                        </key>
                        <key index="1">
                            <id>32</id>
                            <name>SELECT</name>
                            <locked>0</locked>
                        </key>
                    </keylist>
                </mode>
                <mode index="5">
                    <name>eTimeoutChangeFB</name>
                    <keylist>
                        <key index="0">
                            <id>49</id>
                            <name>DONE</name>
                            <locked>0</locked>
                        </key>
                    </keylist>
                </mode>
                <mode index="6">
                    <name>eNameChange</name>
                    <keylist>
                        <key index="0">
                            <id>49</id>
                            <name>CANCEL</name>
                            <locked>0</locked>
                        </key>
                        <key index="1">
                            <id>50</id>
                            <name>CHANGE CASE</name>
                            <locked>0</locked>
                        </key>
                        <key index="2">
                            <id>51</id>
                            <name>CLEAR</name>
                            <locked>0</locked>
                        </key>
                        <key index="3">
                            <id>52</id>
                            <name>SAVE</name>
                            <locked>0</locked>
                        </key>
                    </keylist>
                </mode>
                <mode index="7">
                    <name>eNameChangeFB</name>
                    <keylist>
                        <key index="0">
                            <id>49</id>
                            <name>CANCEL</name>
                            <locked>0</locked>
                        </key>
                        <key index="1">
                            <id>50</id>
                            <name>CHANGE CASE</name>
                            <locked>0</locked>
                        </key>
                        <key index="2">
                            <id>51</id>
                            <name>CLEAR</name>
                            <locked>0</locked>
                        </key>
                        <key index="3">
                            <id>52</id>
                            <name>SAVE</name>
                            <locked>0</locked>
                        </key>
                    </keylist>
                </mode>
                <mode index="8">
                    <name>eDateChange</name>
                    <keylist>
                        <key index="0">
                            <id>49</id>
                            <name>BACK</name>
                            <locked>0</locked>
                        </key>
                        <key index="1">
                            <id>50</id>
                            <name>MONTH</name>
                            <locked>0</locked>
                        </key>
                        <key index="2">
                            <id>51</id>
                            <name>DAY</name>
                            <locked>0</locked>
                        </key>
                        <key index="3">
                            <id>52</id>
                            <name>YEAR</name>
                            <locked>0</locked>
                        </key>
                    </keylist>
                </mode>
                <mode index="9">
                    <name>eDateChangeFB</name>
                    <keylist>
                        <key index="0">
                            <id>49</id>
                            <name>DONE</name>
                            <locked>0</locked>
                        </key>
                        <key index="1">
                            <id>50</id>
                            <name>MONTH</name>
                            <locked>0</locked>
                        </key>
                        <key index="2">
                            <id>51</id>
                            <name>DAY</name>
                            <locked>0</locked>
                        </key>
                        <key index="3">
                            <id>52</id>
                            <name>YEAR</name>
                            <locked>0</locked>
                        </key>
                    </keylist>
                </mode>
                <mode index="10">
                    <name>eTimeChange</name>
                    <keylist>
                        <key index="0">
                            <id>49</id>
                            <name>BACK</name>
                            <locked>0</locked>
                        </key>
                        <key index="1">
                            <id>50</id>
                            <name>HOUR</name>
                            <locked>0</locked>
                        </key>
                        <key index="2">
                            <id>51</id>
                            <name>MINUTE</name>
                            <locked>0</locked>
                        </key>
                        <key index="3">
                            <id>52</id>
                            <name>AM/PM</name>
                            <locked>0</locked>
                        </key>
                    </keylist>
                </mode>
                <mode index="11">
                    <name>eTimeChangeFB</name>
                    <keylist>
                        <key index="0">
                            <id>49</id>
                            <name>DONE</name>
                            <locked>0</locked>
                        </key>
                        <key index="1">
                            <id>50</id>
                            <name>HOUR</name>
                            <locked>0</locked>
                        </key>
                        <key index="2">
                            <id>51</id>
                            <name>MINUTE</name>
                            <locked>0</locked>
                        </key>
                        <key index="3">
                            <id>52</id>
                            <name>AM/PM</name>
                            <locked>0</locked>
                        </key>
                    </keylist>
                </mode>
                <mode index="12">
                    <name>eMessage</name>
                    <keylist>
                        <key index="0">
                            <id>49</id>
                            <name>OK</name>
                            <locked>0</locked>
                        </key>
                    </keylist>
                </mode>
            </modelist>
        </page>
        <page index="11">
            <name>AdministrationScreen</name>
            <locked>0</locked>
            <modelist>
                <mode index="0">
                    <name>eNormal</name>
                    <keylist>
                        <key index="0">
                            <id>49</id>
                            <name>BACK</name>
                            <locked>0</locked>
                        </key>
                        <key index="1">
                            <id>32</id>
                            <name>SELECT</name>
                            <locked>0</locked>
                        </key>
                    </keylist>
                    <rowlist>
                        <row index="0">
                            <name>Format SD Card</name>
                            <locked>0</locked>
                        </row>
                        <row index="1">
                            <name>Restore Factory Defaults</name>
                            <locked>0</locked>
                        </row>
                        <row index="2">
                            <name>About this myMix</name>
                            <locked>0</locked>
                        </row>
                        <row index="3">
                            <name>Update IEX16 Firmware</name>
                            <locked>0</locked>
                        </row>
                    </rowlist>
                </mode>
                <mode index="1">
                    <name>eFormat</name>
                    <keylist>
                        <key index="0">
                            <id>49</id>
                            <name>BACK</name>
                            <locked>0</locked>
                        </key>
                        <key index="1">
                            <id>32</id>
                            <name>SELECT</name>
                            <locked>0</locked>
                        </key>
                    </keylist>
                    <rowlist>
                        <row index="0">
                            <name>Format SD Card</name>
                            <locked>0</locked>
                        </row>
                        <row index="1">
                            <name>Restore Factory Defaults</name>
                            <locked>0</locked>
                        </row>
                        <row index="2">
                            <name>About this myMix</name>
                            <locked>0</locked>
                        </row>
                        <row index="3">
                            <name>Update IEX16 Firmware</name>
                            <locked>0</locked>
                        </row>
                    </rowlist>
                </mode>
                <mode index="2">
                    <name>eFormatting</name>
                </mode>
                <mode index="3">
                    <name>eMessage</name>
                    <keylist>
                        <key index="0">
                            <id>49</id>
                            <name>OK</name>
                            <locked>0</locked>
                        </key>
                    </keylist>
                </mode>
                <mode index="4">
                    <name>eRestoreMessage</name>
                    <keylist>
                        <key index="0">
                            <id>49</id>
                            <name>OK</name>
                            <locked>0</locked>
                        </key>
                    </keylist>
                </mode>
                <mode index="5">
                    <name>eFormatConfirm</name>
                    <keylist>
                        <key index="0">
                            <id>49</id>
                            <name>YES</name>
                            <locked>0</locked>
                        </key>
                        <key index="1">
                            <id>50</id>
                            <name>NO</name>
                            <locked>0</locked>
                        </key>
                    </keylist>
                </mode>
                <mode index="6">
                    <name>eFormatConfirm2</name>
                    <keylist>
                        <key index="0">
                            <id>49</id>
                            <name>YES</name>
                            <locked>0</locked>
                        </key>
                        <key index="1">
                            <id>50</id>
                            <name>NO</name>
                            <locked>0</locked>
                        </key>
                    </keylist>
                </mode>
                <mode index="7">
                    <name>eRestoreConfirm</name>
                    <keylist>
                        <key index="0">
                            <id>49</id>
                            <name>YES</name>
                            <locked>0</locked>
                        </key>
                        <key index="1">
                            <id>50</id>
                            <name>NO</name>
                            <locked>0</locked>
                        </key>
                    </keylist>
                </mode>
                <mode index="8">
                    <name>eRestoreConfirm2</name>
                    <keylist>
                        <key index="0">
                            <id>49</id>
                            <name>YES</name>
                            <locked>0</locked>
                        </key>
                        <key index="1">
                            <id>50</id>
                            <name>NO</name>
                            <locked>0</locked>
                        </key>
                    </keylist>
                </mode>
                <mode index="9">
                    <name>eUpdateIEX16LFirmware</name>
                    <keylist>
                        <key index="0">
                            <id>49</id>
                            <name>DONE</name>
                            <locked>0</locked>
                        </key>
                    </keylist>
                </mode>
                <mode index="10">
                    <name>eDone</name>
                    <keylist>
                        <key index="0">
                            <id>49</id>
                            <name>DONE</name>
                            <locked>0</locked>
                        </key>
                    </keylist>
                </mode>
            </modelist>
        </page>
    </pagelist>
</locks>
XML;
}

/* End of mymix_lock.php*/
