<?php

// Model to handle interactions with MyMix preferences
class MyMix_Preference
{
	private $default_xml = <<<XML
<?xml version="1.0" encoding="iso-8859-1"?>
<Preferences>
    <UnitName>DEFAULT</UnitName>
    <Brightness>3</Brightness>
    <ActivityTimeout>5</ActivityTimeout>
    <CurrentProfile>PROFILE 1</CurrentProfile>
    <UIViewType>0</UIViewType>
</Preferences>
XML;

	private $pref_data;
	private $pref_path;

	function __construct($filename)
	{
		if(file_exists($filename))
		{
			$this->load($filename);
		}
		else
		{
			$this->pref_data = new SimpleXMLElement($this->default_xml);
			$this->pref_path = $filename;
		}
	}

	private function load($filename)
	{
		libxml_use_internal_errors(true);
		$retval = simplexml_load_file($filename);
		if($retval === FALSE)
		{
			$errors = libxml_get_errors();
			$error_message = "";
			foreach ($errors as $error)
			{
				$error_message .= $error->message . " in " . $error->file . " at line " . $error->line . ".\n";
			}

			throw new Exception("Failed to open file: " . $error_message);
		}

		$this->pref_data = $retval;
		$this->pref_path = $filename;
	}

	public function save()
	{
		$path = dirname($this->pref_path);
		if(!is_dir($path))
		{
			mkdir($path, 0777, TRUE);
		}
		$result = file_put_contents($this->pref_path, $this->pref_data->saveXML());
		if($result === FALSE)
		{
			$error = error_get_last();
			throw new Exception("Failed to open file: " . $error['message']);
		}
	}

	public function set_unit_name($name)
	{
		$this->pref_data->UnitName = $name;
	}

	public function get_unit_name()
	{
		return (string)$this->pref_data->UnitName;
	}

	public function set_brightness($bright)
	{
		$this->pref_data->Brightness = $bright;
	}

	public function get_brightness()
	{
		return (int)$this->pref_data->Brightness;
	}

	public function set_activity_timeout($time)
	{
		$this->pref_data->ActivityTimeout = $time;
	}

	public function get_activity_timeout()
	{
		return (int)$this->pref_data->ActivityTimeout;
	}

	public function set_current_profile($profile_name)
	{
		$this->pref_data->CurrentProfile = $profile_name;
	}

	public function get_current_profile()
	{
		return (string)$this->pref_data->CurrentProfile;
	}

	public function set_ui_view_type($type)
	{
		$this->pref_data->UIViewType = $type;
	}

	public function get_ui_view_type()
	{
		return (int)$this->pref_data->UIViewType;
	}

	// Helper function for other pref list functions
	private static function pref_list_helper($folder)
	{
		$retval = array();

		$prefs = array();
		if(is_dir($folder))
		{
			exec("ls " . $folder, $prefs);
		}

		foreach($prefs as $this_pref)
		{
			$retval[$this_pref] = $this_pref;
		}

		return $retval;
	}

	public static function get_local_saved_prefs()
	{
		require_once("helpers/config.php");

		$path = Config::get_item('saved_mymix_prefs_dir');
		return self::pref_list_helper($path);
	}

	public static function get_external_saved_prefs()
	{
		require_once("helpers/config.php");

		$path = Config::get_item('external_mymix_prefs_dir');
		return self::pref_list_helper($path);
	}

	public static function delete_local_saved_pref($pref_name)
	{
		$path = Config::get_item('saved_mymix_prefs_dir') . $pref_name;
		unlink($path);
	}
}

/* End of mymix_preference.php*/
