<?php

class Project_File {
	private static $default_xml = <<< XML
<?xml version="1.0" encoding="iso-8859-1"?>
<project>
	<name>Project 1</name>
	<author>Unknown</author>
	<description>Project description</description>
	<devicelabels>
		<label>
			<name>Label1</name>
			<mac>ff:ff:ff:ff:ff:ff</mac>
		</label>
	</devicelabels>
</project>
XML;

	private $xml_data;
	private $xml_path;

	function __construct($filename)
	{
		if(file_exists($filename))
		{
			$this->load($filename);
		}
		else
		{
			$this->xml_data = new SimpleXMLElement(self::$default_xml);
			$this->xml_path = $filename;
		}
	}

	private function load($filename)
	{
		libxml_use_internal_errors(true);
		$retval = simplexml_load_file($filename);
		if($retval === FALSE)
		{
			$errors = libxml_get_errors();
			$error_message = "";
			foreach ($errors as $error)
			{
				$error_message .= $error->message . " in " . $error->file . " at line " . $error->line . ".\n";
			}

			throw new Exception("Failed to open file: " . $error_message);
		}

		$this->xml_data = $retval;
		$this->xml_path = $filename;
	}

	public function save()
	{
		$result = file_put_contents($this->xml_path, $this->xml_data->saveXML());
		if($result === FALSE)
		{
			$error = error_get_last();
			throw new Exception("Failed to save file: " . $error['message']);
		}
	}

	public function get_label($id)
	{
		$retval = "";

		foreach($this->xml_data->devicelabels->children() as $this_label)
		{
			$this_id = (int)$this_label->id;
			if($this_id == $id)
			{
				$retval = $this_label;
				break;
			}
		}

		return $retval;
	}

	public function get_label_for_mac($mac)
	{
		$retval = "";

		foreach($this->xml_data->devicelabels->children() as $this_label)
		{
			if($this_label->mac == $mac)
			{
				$retval = (string)$this_label->name;
				break;
			}
		}

		return $retval;
	}

	public function get_mac_for_label($label)
	{
		$retval = "";

		foreach($this->xml_data->devicelabels->children() as $this_label)
		{
			if($this_label->name == $label)
			{
				$retval = (string)$this_label->mac;
				break;
			}
		}

		return $retval;
	}

	public function get_all_labels()
	{
		$retval = array();

		foreach($this->xml_data->devicelabels->children() as $this_label)
		{
			$retval[] = array('id' => (int)$this_label->id, 'name' => (string)$this_label->name, 'mac' => (string)$this_label->mac);
		}

		return $retval;
	}

	public function add_label($mac, $name)
	{
		$this->save_label(0, $mac, $name);
	}

	// Passing id of 0 means that a new item will always be added
	public function save_label($id, $mac, $name)
	{
		$foundit = FALSE;
		$last_id = 0;
		foreach($this->xml_data->devicelabels->children() as $this_label)
		{
			if($id > 0 && $this_label->id == $id)
			{
				$foundit = TRUE;
				// Update the node
				$this_label->mac = $mac;
				$this_label->name = $name;
			}
			$last_id = (int)$this_label->id;
		}
		if(!$foundit)
		{
			$new_label = $this->xml_data->devicelabels->addChild("label");
			$new_label->addChild("id", $last_id + 1);
			$new_label->addChild("name", $name);
			$new_label->addChild("mac", $mac);
		}
	}

	public function delete_label($id)
	{
		foreach($this->xml_data->devicelabels->children() as $this_label)
		{
			if($this_label->id == $id)
			{
				// delete label
				$oNode = dom_import_simplexml($this_label);
				$oNode->parentNode->removeChild($oNode);
				break;
			}
		}
	}

	public function get_name()
	{
		return (string)$this->xml_data->name;
	}

	public function set_name($name)
	{
		$this->xml_data->name = $name;
	}

	public function get_author()
	{
		return (string)$this->xml_data->author;
	}

	public function set_author($author)
	{
		$this->xml_data->author = $author;
	}

	public function get_description()
	{
		return (string)$this->xml_data->description;
	}

	public function set_description($description)
	{
		$this->xml_data->description = $description;
	}
}

/* End of project_file.php */
