<?php
	require_once("models/login.php");
	require_once("helpers/input.php");
	require_once("models/mymix_profile.php");
	require_once("helpers/ftp.php");
	require_once("models/avahi.php");
	require_once("helpers/form.php");
	require_once("helpers/validate.php");
	require_once("models/iex16_profile.php");
	require_once("models/mymix_preference.php");

	Login::require_login();

	$mac = Input::get('mac');
	$profile_name = Input::get('profile_name');

	// if this device is online, pull the profile
	$avahi_devices = Avahi::get_devices("all");
	foreach($avahi_devices as $this_device)
	{
		if($this_device['mac'] == $mac)
		{
			// Found the device

			// Tell myMix to write the current profile to flash
			FTP::pull_mymix_preference($this_device['ip_address'], $mac);
			FTP::push_mymix_preference($this_device['ip_address'], $mac);

			// Pull profile from it
			FTP::pull_mymix_profile($this_device['ip_address'], $mac, $profile_name);
			break;
		}
	}

	$prefs = new MyMix_Preference(Config::get_item('mymix_devices_dir') . $mac . "/prefs");
	$profile = new MyMix_Profile(Config::get_item('mymix_devices_dir') . $mac . "/profiles/" . $profile_name);

	// array to track which devices have been synced
	$synced_devices = array();

	$channels = array();
	for($channel_num = 0; $channel_num < $profile->get_remote_channel_count(); $channel_num++)
	{
		// Remove local channels from list
		if($profile->get_remote_channel_unit_name($channel_num) == $prefs->get_unit_name())
		{
			continue;
		}

		$channels[$channel_num]['unit_name'] = $profile->get_remote_channel_unit_name($channel_num);
		$channels[$channel_num]['remote_channel_name'] = $profile->get_remote_channel_name($channel_num);
		$channels[$channel_num]['selected'] = ($profile->get_remote_channel_selected($channel_num) == 1);
		$channels[$channel_num]['online'] = FALSE;
		foreach($avahi_devices as $this_device)
		{
			if($this_device['name'] == $profile->get_remote_channel_unit_name($channel_num))
			{
				// found the device

				// sync the device if it hasn't been already
				if(!in_array($this_device['name'], $synced_devices))
				{
					$synced_devices[] = $this_device['name'];
					if($this_device['type'] == "mymix")
					{
						FTP::pull_mymix_preference($this_device['ip_address'], $this_device['mac']);
						$remote_device_prefs = new MyMix_Preference(Config::get_item('mymix_devices_dir') .
							$this_device['mac'] . "/prefs");
						// only pull the current profile - no need to pull the rest for this page
						FTP::pull_mymix_profile($this_device['ip_address'],
							$this_device['mac'],
							$remote_device_prefs->get_current_profile());
					}
					else
					{
						FTP::pull_iex16_profile($this_device['ip_address'], $this_device['mac']);
					}
				}

				// compare remote device's channels
				if($this_device['type'] == "mymix")
				{
					$remote_device_prefs = new MyMix_Preference(Config::get_item('mymix_devices_dir') .
						$this_device['mac'] . "/prefs");
					$remote_device_profile = new MyMix_Profile(Config::get_item('mymix_devices_dir') .
						$this_device['mac'] . "/profiles/" . $remote_device_prefs->get_current_profile());
					if($remote_device_profile->get_ch1_name() == $profile->get_remote_channel_name($channel_num) ||
						$remote_device_profile->get_ch2_name() == $profile->get_remote_channel_name($channel_num))
					{
						$channels[$channel_num]['online'] = TRUE;
						// found the device and channel
						// break out of avahi devices loop
						break;
					}
				}
				else
				{
					$remote_device_prefs = new IEX16_Profile(Config::get_item('iex16_devices_dir') .
						$this_device['mac'] . "/prefs");
					for($prefs_chan = 0; $prefs_chan < 16; $prefs_chan++)
					{
						/*$modified_channel_name = sprintf("%02d %s", 
							($prefs_chan + 1), 
							$remote_device_prefs->get_channel_name($prefs_chan));*/
						$modified_channel_name = $remote_device_prefs->get_channel_name($prefs_chan);

						if($modified_channel_name == $profile->get_remote_channel_name($channel_num))
						{
							$channels[$channel_num]['online'] = TRUE;
							// break out of remote device prefs loop
							break;
						}
						if($channels[$channel_num]['online'])
						{
							// found the device and channel
							// break out of avahi devices loop
							break;
						}
					}
				}
			}
		}
	}

	$input_mode_options = array(
		"mono" => "Mono",
		"dual" => "Dual Mono",
		"stereo" => "Stereo",
		"none" => "None"
	);

	// Header data
	$title = "MyMix Control - Edit Channel Select";
    $ID = "edit_mymix";

	require("views/header.php");
	require("views/mymix-channel-select.php");
	require("views/footer.php");

/* End of mymix-edit-channel-select.php */
