<?php
	require_once("models/login.php");
	require_once("helpers/input.php");
	require_once("models/mymix_profile.php");
	require_once("helpers/ftp.php");
	require_once("models/avahi.php");
	require_once("helpers/form.php");
	require_once("models/iex16_profile.php");
	require_once("models/mymix_preference.php");
	require_once("helpers/validate.php");

	Login::require_login();

	$mac = Input::get('mac');
	$profile_name = Input::get('profile_name');

	// if this device is online, pull the profile
	$avahi_devices = Avahi::get_devices("all");
	foreach($avahi_devices as $this_device)
	{
		if($this_device['mac'] == $mac)
		{
			// Found the device

			// Tell myMix to write the current profile to flash
			FTP::pull_mymix_preference($this_device['ip_address'], $mac);
			FTP::push_mymix_preference($this_device['ip_address'], $mac);

			// Pull profile from it
			FTP::pull_mymix_profile($this_device['ip_address'], $mac, $profile_name);
			break;
		}
	}

	$prefs = new MyMix_Preference(Config::get_item('mymix_devices_dir') . $mac . "/prefs");
	$profile = new MyMix_Profile(Config::get_item('mymix_devices_dir') . $mac . "/profiles/" . $profile_name);
	$channels = array();
	$synced_devices = array();
	for($channel_num = 0; $channel_num < $profile->get_remote_channel_count(); $channel_num++)
	{
		$channels[$channel_num]['unit_name'] = $profile->get_remote_channel_unit_name($channel_num);
		$channels[$channel_num]['remote_channel_name'] = $profile->get_remote_channel_name($channel_num);
		$channels[$channel_num]['remote_channel_volume'] = $profile->get_remote_channel_volume($channel_num);
		$channels[$channel_num]['remote_channel_tone'] = $profile->get_remote_channel_tone($channel_num);
		$channels[$channel_num]['remote_channel_effect_send'] = $profile->get_remote_channel_effect_send($channel_num);
		$channels[$channel_num]['remote_channel_pan'] = $profile->get_remote_channel_pan($channel_num);
		$channels[$channel_num]['remote_channel_solo'] = ($profile->get_remote_channel_solo($channel_num) == "on");
		$channels[$channel_num]['remote_channel_mute'] = ($profile->get_remote_channel_mute($channel_num) == "on");
		foreach($avahi_devices as $this_device)
		{
			$formatted_mac = Validate::format_mac_address($profile->get_remote_channel_mac($channel_num));
			if($this_device['mac'] == $formatted_mac)
			{
				// found the device

				// sync the device if it hasn't been already
				if(!in_array($this_device['name'], $synced_devices))
				{
					$synced_devices[] = $this_device['name'];
					if($this_device['type'] == "mymix")
					{
						FTP::pull_mymix_preference($this_device['ip_address'], $this_device['mac']);
						$remote_device_prefs = new MyMix_Preference(Config::get_item('mymix_devices_dir') .
							$this_device['mac'] . "/prefs");
						// only pull the current profile - no need to pull the rest for this page
						FTP::pull_mymix_profile($this_device['ip_address'],
							$this_device['mac'],
							$remote_device_prefs->get_current_profile());
					}
					else
					{
						FTP::pull_iex16_profile($this_device['ip_address'], $this_device['mac']);
					}
				}

				// compare remote device's channels
				if($this_device['type'] == "mymix")
				{
					$remote_device_prefs = new MyMix_Preference(Config::get_item('mymix_devices_dir') .
						$this_device['mac'] . "/prefs");
					$remote_device_profile = new MyMix_Profile(Config::get_item('mymix_devices_dir') .
						$this_device['mac'] . "/profiles/" . $remote_device_prefs->get_current_profile());
					// Check the remote channel names and input mode.
					// Also check that the remote device input mode is not "none".
					if( ($remote_device_profile->get_ch1_name() == $profile->get_remote_channel_name($channel_num) ||
						$remote_device_profile->get_ch2_name() == $profile->get_remote_channel_name($channel_num)) &&
						$remote_device_profile->get_input_mode() == $profile->get_remote_channel_input_mode($channel_num) &&
						$remote_device_profile->get_input_mode() != "none"
					)
					{
						$channels[$channel_num]['online'] = TRUE;
						// found the device and channel
						// break out of avahi devices loop
						break;
					}
				}
				else
				{
					$remote_device_prefs = new IEX16_Profile(Config::get_item('iex16_devices_dir') .
						$this_device['mac'] . "/prefs");
					for($prefs_chan = 0; $prefs_chan < 16; $prefs_chan++)
					{
						/*$modified_channel_name = sprintf("%02d %s", 
							($prefs_chan + 1), 
							$remote_device_prefs->get_channel_name($prefs_chan));*/
						$modified_channel_name = $remote_device_prefs->get_channel_name($prefs_chan);

						// Convert IEX16 input mode values to those stored in the remotechannels section.
						$modified_input_mode = "";
						switch($remote_device_prefs->get_channel_input_mode($prefs_chan))
						{
							case "N":
								$modified_input_mode = "none";
								break;
							case "DM":
								$modified_input_mode = "dual";
								break;
							case "S":
								$modified_input_mode = "stereo";
								break;
						}

						// Match channels on name and input mode.
						// Channels with input mode of none are considered offline.
						$channels[$channel_num]['online'] = FALSE;
						if($modified_channel_name == $profile->get_remote_channel_name($channel_num) &&
							$modified_input_mode == $profile->get_remote_channel_input_mode($channel_num) &&
							$modified_input_mode != "none"
						)
						{
							$channels[$channel_num]['online'] = TRUE;
							// break out of remote device prefs loop
							break;
						}
						if($channels[$channel_num]['online'])
						{
							// found the device and channel
							// break out of avahi devices loop
							break;
						}
					}
				}
			}
		}
	}

	// Volume options
	for($volume = 0; $volume <= 100; $volume++)
	{
		$volume_options[$volume] = $volume . "%";
	}

	// Tone options
	for($tone = 0; $tone <= 24; $tone++)
	{
		if($tone < 12)
		{
			$tone_options[$tone] = ( (24 - $tone) - 12) . " Bass";
		}
		elseif($tone == 12)
		{
			$tone_options[$tone] = "Flat";
		}
		else
		{
			$tone_options[$tone] = ($tone - 12) . " Treble";
		}
	}

	// Effect send options
	for($effect_send = 0; $effect_send <= 100; $effect_send++)
	{
		$effect_send_options[$effect_send] = $effect_send . "%";
	}

	// Pan options
	for($pan = 0; $pan <= 100; $pan++)
	{
		$pan_options[$pan] = (100 - $pan) . "% L, " . $pan . "% R";
	}

	// Header data
	$title = "MyMix Control - Edit Mix";
    $ID = "edit_mymix";

	require("views/header.php");
	require("views/mymix-mix.php");
	require("views/footer.php");

/* End of mymix-edit-mix.php */
